<?php
/**
 * Zeen Helpers
 *
 * @copyright   Copyright Codetipi
 * @since       1.0.0
*/
namespace Zeen;

class ZeenHelpers {

	/**
	 * Args
	 *
	 * @since 1.0.0
	 */
	public static function zeen_args() {

		$output                          = array();
		$output['siteUrl']               = get_site_url();
		$output['wooStockFormat']        = get_option( 'woocommerce_stock_format' );
		$output['sDelay']                = get_theme_mod( 'slider_args_autoplay', 1 ) == 1 ? get_theme_mod( 'slider_args_delay', 5 ) * 1000 : false;
		$output['galleryAutoplay']       = apply_filters( 'zeen_gallery_autoplay', false );
		$output['subL']                  = get_theme_mod( 'subscribe_on_leave' ) == 1 ? true : false;
		$output['lazy']                  = get_theme_mod( 'lazy', 1 ) == 1 ? true : false;
		$output['lazyNative']            = get_theme_mod( 'lazy_native' ) == 1 ? true : false;
		$output['iconSorter']            = '<i class="tipi-i-chevron-down"></i>';
		$output['iplComs']               = get_theme_mod( 'ipl_coms' ) == 1 ? true : false;
		$output['heroFade']              = apply_filters( 'zeen_hero_fade_opacity', 0.075 );
		$output['iplMob']                = get_theme_mod( 'ipl_mobile', 1 ) == 1 ? true : false;
		$output['infUrlChange']          = get_theme_mod( 'infinite_scroll_url', 1 ) == 1 ? true : false;
		$output['fbComs']                = get_theme_mod( 'fb_comments' ) == 1 ? true : false;
		$output['lightbox']              = get_theme_mod( 'lightbox', 1 ) == 1 && zeen_load_check( array( 'script' => 'lightbox' ) ) ? true : false;
		$output['lightboxChoice']        = get_theme_mod( 'lightbox_choice', 1 );
		$output['archiveUrlChange']      = get_theme_mod( 'archive_url_change' ) == 1 ? true : false;
		$output['stickyHeaderCustomize'] = get_theme_mod( 'sticky_header_customize' ) == 1 ? true : false;
		$output['toolTipFont']           = get_theme_mod( 'typo_tooltip', 2 );
		$output['wooAjaxSinglebutton']   = get_theme_mod( 'woo_ajax_single_button', 1 );
		$output['cookieDuration']        = apply_filters( 'zeen_cookie_duration_in_days', 90 );
		$output['slidingBoxStartPoint']  = apply_filters( 'zeen_sliding_box_start_point', 0 );
		$output['browserMode']           = get_theme_mod( 'detect_browser_mode' ) == 1 ? true : false;
		$output['searchPpp']             = apply_filters( 'zeen_search_number_of_posts', 3 );
		$output['polyfill']              = get_parent_theme_file_uri( 'assets/js/polyfill.min.js' );
		$output['iplCached']             = apply_filters( 'zeen_ipl_cached', true );
		$disqus                          = false;
		$path                            = '/';
		if ( function_exists( 'get_blog_details' ) ) {
			$path = get_blog_details();
			$path = empty( $path->path ) ? '' : $path->path;
		}
		$output['path'] = $path;
		if ( class_exists( 'Disqus' ) ) {
			$disqus = get_option( 'disqus_forum_url' );
			if ( ! empty( $disqus ) ) {
				$disqus = strtolower( $disqus );
			}
		}
		$output['disqus']     = $disqus;
		$output['subCookie']  = get_theme_mod( 'subscribe_leave_cookie', 1 ) == 1 ? true : false;
		$output['pluginsUrl'] = plugins_url();
		$output['frontpage']  = is_front_page();
		$ipl                  = apply_filters( 'zeen_infinite_post_ajax', array() );
		if ( class_exists( 'Jetpack_Tiled_Gallery' ) ) {
			$ipl[] = 'jetpack/modules/tiled-gallery/tiled-gallery/tiled-gallery.js';
		}
		if ( class_exists( 'aesopStoryTheme' ) ) {
			$ipl[] = 'aesop-story-engine/public/assets/js/ai-core.min.js';
		}
		if ( class_exists( 'Lets_Review_Blocks' ) ) {
			$ipl[] = 'lets-review/assets/js/functions.min.js';
		}
		$output['ipl'] = $ipl;
		return $output;

	}

	/**
	 * Admin Args
	 *
	 * @since 1.0.0
	 */
	public static function zeen_admin_args() {

		$output = array();
		global $post;

		if ( ! empty( $post->post_type ) ) {
			$output['postType'] = $post->post_type;
			if ( ! empty( $post->ID ) ) {
				$output['builderActive']   = get_post_meta( $post->ID, 'tipi_builder_active', true );
				$button_text               = empty( $output['builderActive'] ) ? esc_attr__( 'Create With Tipi Builder', 'zeen' ) : esc_attr__( 'Edit With Tipi Builder', 'zeen' );
				$output['tipiBuilderLogo'] = array( esc_url( get_parent_theme_file_uri( 'inc/builder/assets/img/tipi-builder-mark-s.png' ) ), esc_url( get_parent_theme_file_uri( 'inc/builder/assets/img/tipi-builder-mark-s@2x.png' ) ) );
				$output['buttonLink']      = \TipiBuilder\ZeenAdminActions::zeen_get_url(
					array(
						'item_id' => $post->ID,
					),
					$button_text
				);
			}
		}

		return $output;
	}

	public static function zeen_get_emotions() {
		return array(
			'confused'    => esc_html__( 'Confused', 'zeen' ),
			'yikes'       => esc_html__( 'Yikes', 'zeen' ),
			'haha'        => esc_html__( 'Haha', 'zeen' ),
			'gross'       => esc_html__( 'Gross', 'zeen' ),
			'cool'        => esc_html__( 'Cool', 'zeen' ),
			'love'        => esc_html__( 'Love It', 'zeen' ),
			'happy'       => esc_html__( 'Happy', 'zeen' ),
			'unimpressed' => esc_html__( 'Okay...', 'zeen' ),
			'sleepy'      => esc_html__( 'Yawn', 'zeen' ),
			'sad'         => esc_html__( 'Sad', 'zeen' ),
			'money'       => esc_html__( 'Money', 'zeen' ),
			'angry'       => esc_html__( 'Angry', 'zeen' ),
			'cry'         => esc_html__( 'Cry', 'zeen' ),
			'kiss'        => esc_html__( 'Kiss', 'zeen' ),
		);
	}

	public static function zeen_emojis( $emoji = 'happy', $style = 1 ) {
		if ( 1 == $style ) {
			if ( 'happy' == $emoji ) {
				?>
				<svg width="56px" height="56px" viewBox="0 0 56 56" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<g fill="#F9BF44">
								<circle cx="28" cy="28" r="27.758"></circle>
							</g>
							<g transform="translate(14.000000, 22.000000)" fill="#382A12">
								<ellipse cx="3.003" cy="3.247" rx="2.5" ry="2.87"></ellipse>
								<ellipse cx="24.997" cy="3.247" rx="2.5" ry="2.87"></ellipse>
								<path d="M14,15.157 C11.1535628,15.1536917 8.84720419,12.8464382 8.845,10 C8.845,9.44771525 9.29271525,9 9.845,9 C10.3972847,9 10.845,9.44771525 10.845,10 C10.845,11.7427345 12.2577655,13.1555 14.0005,13.1555 C15.7432345,13.1555 17.156,11.7427345 17.156,10 C17.156,9.44771525 17.6037153,9 18.156,9 C18.7082847,9 19.156,9.44771525 19.156,10 C19.1510477,12.8456884 16.8456874,15.1514958 14,15.157 Z"></path>
							</g>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'cry' == $emoji ) {
				?>
				<svg width="56px" height="56px" viewBox="0 0 56 56" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<g fill="#F9BF44">
								<circle cx="28" cy="28" r="27.758"></circle>
							</g>
							<g transform="translate(10.000000, 14.000000)">
								<path d="M13.29,10.81 C13.2815549,10.7513207 13.2573641,10.6960273 13.22,10.65 C13.1670572,10.5366829 13.0882823,10.4373581 12.99,10.36 C12.9440169,10.3210027 12.8936834,10.287447 12.84,10.26 C12.690648,10.175044 12.521824,10.130254 12.35,10.1297745 C12.2616481,10.127827 12.1736131,10.1413708 12.09,10.17 C12.0790075,10.1686768 12.0680001,10.172346 12.06,10.18 C11.9883127,10.1918189 11.9200625,10.2191191 11.86,10.26 C11.7495351,10.3175258 11.6537437,10.3996328 11.58,10.5 C11.5410994,10.542428 11.5075182,10.5894417 11.48,10.64 C11.4593973,10.6712156 11.4426109,10.7047885 11.43,10.74 C10.6054015,12.3625497 8.94117766,13.3862385 7.12111925,13.3904565 C5.30106084,13.3946744 3.63211015,12.3787103 2.8,10.76 C2.79883159,10.733798 2.78816809,10.7089165 2.77,10.69 C2.72854531,10.6026881 2.67465147,10.5218474 2.61,10.45 C2.54977997,10.3822176 2.47883568,10.3247865 2.4,10.28 C2.32933931,10.2342731 2.25163407,10.2004882 2.17,10.18 C2.16199988,10.172346 2.15099251,10.1686768 2.14,10.17 C2.05620476,10.1421182 1.96830097,10.1285946 1.88,10.1297745 C1.708176,10.130254 1.53935202,10.175044 1.39,10.26 C1.33944701,10.2875267 1.2924343,10.3211072 1.25,10.36 C1.17348356,10.4199101 1.1061086,10.4906538 1.05,10.57 C1.02284193,10.6111623 0.999415487,10.6546686 0.98,10.7 C0.949721154,10.7524972 0.929381152,10.8101272 0.92,10.87 C0.891370839,10.9536131 0.877826978,11.0416481 0.88,11.13 L0.88,35.35 C0.880092093,35.6154855 0.984198858,35.8703675 1.17,36.06 C1.22,36.1 1.27,36.15 1.33,36.19 C4.53473545,38.6056103 8.22686543,40.2947086 12.15,41.14 C12.2160138,41.1520809 12.2829012,41.1587696 12.35,41.16 C12.9022847,41.16 13.35,40.7122847 13.35,40.16 L13.35,11.1 C13.3522515,11.0246723 13.3386228,10.9497142 13.31,10.88 C13.309439,10.8553388 13.3025522,10.8312352 13.29,10.81 Z" fill="#58B3DE"></path>
								<path d="M35.3,10.87 C35.2906412,10.8101215 35.2702997,10.7524876 35.24,10.7 C35.2206087,10.6546569 35.1971811,10.6111486 35.17,10.57 C35.1175026,10.4909095 35.0534594,10.4201249 34.98,10.36 C34.9357287,10.3187845 34.8850725,10.2850137 34.83,10.26 C34.680648,10.175044 34.511824,10.130254 34.34,10.1297745 C34.251699,10.1285946 34.1637952,10.1421182 34.08,10.17 C34.0690075,10.1686768 34.0580001,10.172346 34.05,10.18 C33.9677373,10.1986047 33.889712,10.2325288 33.82,10.28 C33.7394078,10.3221627 33.6680194,10.3799533 33.61,10.45 C33.5491679,10.5055376 33.5013613,10.5738328 33.47,10.65 C33.4495999,10.6777683 33.4327995,10.7080091 33.42,10.74 C32.5957065,12.3656614 30.9276998,13.3900743 29.105,13.3900743 C27.2823002,13.3900743 25.6142935,12.3656614 24.79,10.74 C24.777443,10.7047655 24.7606534,10.6711863 24.74,10.64 C24.7124902,10.5894364 24.6789083,10.5424217 24.64,10.5 C24.5662563,10.3996328 24.4704649,10.3175258 24.36,10.26 C24.2999375,10.2191191 24.2316873,10.1918189 24.16,10.18 C24.1519999,10.172346 24.1409925,10.1686768 24.13,10.17 C24.0463869,10.1413708 23.9583519,10.127827 23.87,10.1297745 C23.698176,10.130254 23.529352,10.175044 23.38,10.26 C23.3294575,10.2875435 23.2824468,10.3211226 23.24,10.36 C23.1396328,10.4337437 23.0575258,10.5295351 23,10.64 C22.9591191,10.7000625 22.9318189,10.7683127 22.92,10.84 C22.912346,10.8480001 22.9086768,10.8590075 22.91,10.87 C22.8813708,10.9536131 22.867827,11.0416481 22.87,11.13 L22.87,40.11 C22.87,40.6622847 23.3177153,41.11 23.87,41.11 C23.9337917,41.1088261 23.9973621,41.1021345 24.06,41.09 L24.08,41.09 C28.004605,40.2107164 31.6881021,38.4799166 34.87,36.02 C34.9415639,35.9814135 35.0058584,35.9306547 35.06,35.87 C35.2386807,35.6846225 35.3389747,35.4374695 35.34,35.18 L35.34,11.13 C35.3421943,11.0416468 35.3286499,10.953608 35.3,10.87 Z" fill="#58B3DE"></path>
								<path d="M7.111,15.388 C4.50301785,15.3988891 2.11947506,13.9144224 0.979,11.569 C0.819923092,11.2481546 0.844559673,10.8667374 1.04359071,10.569023 C1.24262176,10.2713086 1.5856593,10.102752 1.94294606,10.1271114 C2.30023282,10.1514707 2.61721843,10.3650268 2.774,10.687 C3.58722753,12.3399958 5.26929098,13.3870718 7.1115,13.3870718 C8.95370902,13.3870718 10.6357725,12.3399958 11.449,10.687 C11.6937083,10.193443 12.2915005,9.99075462 12.7859281,10.233699 C13.2803558,10.4766434 13.4851774,11.073708 13.244,11.569 C12.1033683,13.9147487 9.7193425,15.3992741 7.111,15.388 L7.111,15.388 Z" fill="#382A12"></path>
								<path d="M5.434,7.79200336 C3.80926726,7.79045484 2.23893046,7.20645701 1.008,6.146 C0.58826359,5.78701491 0.539014913,5.15573641 0.898,4.736 C1.25698509,4.31626359 1.88826359,4.26701491 2.308,4.626 C3.70774967,5.82316545 5.66627357,6.12064358 7.35836605,5.39309477 C9.05045854,4.66554597 10.1819123,3.03947051 10.276,1.2 C10.2938633,0.842734406 10.5009685,0.522137328 10.8193013,0.358974584 C11.137634,0.195811839 11.5188318,0.214871732 11.8193013,0.408974584 C12.1197707,0.603077436 12.2938633,0.942734407 12.276,1.3 C12.1566004,3.90556304 10.5541701,6.21202084 8.154,7.233 C7.2948867,7.60269973 6.36928215,7.79292508 5.434,7.79200336 Z" fill="#382A12"></path>
								<path d="M30.566,7.792 C29.6310437,7.79107368 28.7061329,7.59914959 27.848,7.228 C25.4478299,6.20702084 23.8453996,3.90056304 23.726,1.295 C23.6983858,0.74271525 24.1237153,0.272614237 24.676,0.245 C25.2282847,0.217385763 25.6983858,0.64271525 25.726,1.195 C25.8185954,3.03497891 26.9492118,4.66227619 28.6412825,5.39096887 C30.3333532,6.11966155 32.2925303,5.82298829 33.693,4.626 C34.1127364,4.26701491 34.7440149,4.31626359 35.103,4.736 C35.4619851,5.15573641 35.4127364,5.78701491 34.993,6.146 C33.7618087,7.20668127 32.1910769,7.79069405 30.566,7.792 Z" fill="#382A12"></path>
								<path d="M29.106,15.388 C26.4976575,15.3992741 24.1136317,13.9147487 22.973,11.569 C22.8139231,11.2481546 22.8385597,10.8667374 23.0375907,10.569023 C23.2366218,10.2713086 23.5796593,10.102752 23.9369461,10.1271114 C24.2942328,10.1514707 24.6112184,10.3650268 24.768,10.687 C25.5812275,12.3399958 27.263291,13.3870718 29.1055,13.3870718 C30.947709,13.3870718 32.6297725,12.3399958 33.443,10.687 C33.5997816,10.3650268 33.9167672,10.1514707 34.2740539,10.1271114 C34.6313407,10.102752 34.9743782,10.2713086 35.1734093,10.569023 C35.3724403,10.8667374 35.3970769,11.2481546 35.238,11.569 C34.0975249,13.9144224 31.7139822,15.3988891 29.106,15.388 L29.106,15.388 Z" fill="#382A12"></path>
								<path d="M23.869,20.48 C23.6898561,20.4797679 23.5140637,20.4314164 23.36,20.34 C20.1088395,18.4829335 16.1286473,18.4386797 12.837,20.223 C12.3545793,20.4919627 11.7454627,20.3189207 11.4765,19.8365 C11.2075373,19.3540793 11.3805793,18.7449627 11.863,18.476 C15.7780212,16.3506332 20.5145566,16.4047456 24.38,18.619 C24.7674482,18.848898 24.953328,19.3094911 24.833978,19.7439157 C24.714628,20.1783404 24.3195209,20.4793182 23.869,20.479 L23.869,20.48 Z" fill="#382A12"></path>
							</g>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'kiss' == $emoji ) {
				?>
				<svg width="56px" height="56px" viewBox="0 0 56 56" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<g fill="#F9BF44">
								<circle cx="28" cy="28" r="27.758"></circle>
							</g>
							<g transform="translate(9.000000, 22.000000)">
								<ellipse fill="#F6262F" cx="7.786" cy="9.826" rx="6.833" ry="4.633"></ellipse>
								<ellipse fill="#F6262F" cx="30.214" cy="9.826" rx="6.833" ry="4.633"></ellipse>
								<path d="M24.762,5.98000201 C24.4164982,5.98069211 24.0951145,5.80298649 23.9119985,5.51000095 C23.7288825,5.2170154 23.7099782,4.85026015 23.862,4.54 C25.0109747,2.20197419 27.3894074,0.720690885 29.9945,0.720690885 C32.5995926,0.720690885 34.9780253,2.20197419 36.127,4.54 C36.3681774,5.03529199 36.1633558,5.63235659 35.6689281,5.87530099 C35.1745005,6.11824538 34.5767083,5.91555702 34.332,5.422 C33.5187725,3.76900422 31.836709,2.72192824 29.9945,2.72192824 C28.152291,2.72192824 26.4702275,3.76900422 25.657,5.422 C25.4889772,5.76299505 25.142143,5.97923361 24.762,5.98000201 Z" fill="#382A12"></path>
								<path d="M13.238,5.98000201 C12.8556049,5.98076527 12.5062534,5.76339102 12.338,5.42 C11.5247725,3.76700422 9.84270902,2.71992824 8.0005,2.71992824 C6.15829098,2.71992824 4.47622753,3.76700422 3.663,5.42 C3.41829169,5.91355702 2.82049954,6.11624538 2.32607188,5.87330099 C1.83164423,5.63035659 1.62682261,5.03329199 1.868,4.538 C3.01697465,2.19997419 5.3954074,0.718690885 8.0005,0.718690885 C10.6055926,0.718690885 12.9840253,2.19997419 14.133,4.538 C14.2850218,4.84826015 14.2661175,5.2150154 14.0830015,5.50800095 C13.8998855,5.80098649 13.5785018,5.97869211 13.233,5.978 L13.238,5.98000201 Z" fill="#382A12"></path>
								<path d="M19,12.167 C18.4477153,12.167 18,11.7192847 18,11.167 C18,10.6147153 18.4477153,10.167 19,10.167 C19.961,10.167 20.63,9.621 20.63,9.13 C20.63,8.639 19.961,8.085 19,8.085 C18.4477153,8.085 18,7.63728475 18,7.085 C18,6.53271525 18.4477153,6.085 19,6.085 C20.8379605,5.94011567 22.4529719,7.29485659 22.63,9.13 C22.4504496,10.9627433 20.8356618,12.3137379 19,12.167 L19,12.167 Z" fill="#382A12"></path>
								<path d="M19,16.249 C18.4477153,16.249 18,15.8012847 18,15.249 C18,14.6967153 18.4477153,14.249 19,14.249 C19.961,14.249 20.63,13.703 20.63,13.212 C20.63,12.721 19.961,12.167 19,12.167 C18.4477153,12.167 18,11.7192847 18,11.167 C18,10.6147153 18.4477153,10.167 19,10.167 C20.8379605,10.0221157 22.4529719,11.3768566 22.63,13.212 C22.4504496,15.0447433 20.8356618,16.3957379 19,16.249 L19,16.249 Z" fill="#382A12"></path>
							</g>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'money' == $emoji ) {
				?>
				<svg width="56px" height="56px" viewBox="0 0 56 56" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<g fill="#F9BF44">
								<circle cx="28" cy="28" r="27.758"></circle>
							</g>
							<g transform="translate(13.000000, 18.000000)">
								<path d="M7.706,16.687 C9.10683938,19.5455856 12.0126271,21.357553 15.196,21.357553 C18.3793729,21.357553 21.2851606,19.5455856 22.686,16.687 C22.8405875,16.3772705 22.8216144,16.0091933 22.636,15.717 C22.4528845,15.4240145 22.1315015,15.2463086 21.786,15.246998 L8.606,15.246998 C8.26049853,15.2463086 7.93911545,15.4240145 7.756,15.717 C7.57038557,16.0091933 7.55141252,16.3772705 7.706,16.687 Z" fill="#C15F1E"></path>
								<path d="M3.814,10.908 C3.7157458,10.908 3.61802927,10.8935024 3.524,10.865 C1.21085153,10.2793557 -0.196899499,7.93756882 0.371,5.62 C1.1796023,3.37173036 3.6520626,2.19849568 5.905,2.994 C6.25526716,3.09025136 6.52579373,3.36887457 6.61167684,3.72182711 C6.69755996,4.07477966 6.58529151,4.44654749 6.31840617,4.69296911 C6.05152082,4.93939074 5.67199556,5.02170781 5.327,4.908 C4.13035246,4.43826584 2.77786834,5.01269368 2.285,6.2 C2.04121518,7.45799325 2.84755268,8.680161 4.1,8.951 C4.57432387,9.09477807 4.87176311,9.56430292 4.79911013,10.0545853 C4.72645714,10.5448677 4.30563622,10.908 3.81,10.908 L3.814,10.908 Z" fill="#434F26"></path>
								<path d="M3.149,17.034 C2.66577614,17.0335432 2.18526545,16.9617699 1.723,16.821 C1.20775737,16.6511801 0.92189257,16.1015078 1.07872648,15.5821651 C1.23556039,15.0628223 1.77788437,14.7632509 2.301,14.907 C3.4954238,15.3742165 4.84405354,14.7992814 5.334,13.614 C5.58023512,12.3576058 4.77543893,11.1352938 3.524,10.865 C3.00875737,10.6951801 2.72289257,10.1455078 2.87972648,9.62616505 C3.03656039,9.1068223 3.57888437,8.8072509 4.102,8.951 C6.41260399,9.53744502 7.81737208,11.8781298 7.248,14.193 C6.65787324,15.9404542 4.99240751,17.0947816 3.149,17.034 L3.149,17.034 Z" fill="#434F26"></path>
								<path d="M3.876,19.3 C3.32371525,19.3 2.876,18.8522847 2.876,18.3 L2.876,1.678 C2.876,1.12571525 3.32371525,0.678 3.876,0.678 C4.42828475,0.678 4.876,1.12571525 4.876,1.678 L4.876,18.3 C4.876,18.8522847 4.42828475,19.3 3.876,19.3 Z" fill="#434F26"></path>
								<path d="M26.194,10.908 C26.0957458,10.9079914 25.9980293,10.8935024 25.904,10.865 C23.5908515,10.2793557 22.1831005,7.93756882 22.751,5.62 C23.0851712,4.53220299 23.8777868,3.64461957 24.921,3.19 C25.9800251,2.71514225 27.1761584,2.64400735 28.284,2.99 C28.7992426,3.1598199 29.0851074,3.7094922 28.9282735,4.22883495 C28.7714396,4.7481777 28.2291156,5.0477491 27.706,4.904 C27.0643452,4.69732452 26.3692037,4.73289983 25.752,5.004 C25.232713,5.22524461 24.8357651,5.66199682 24.665,6.2 C24.4202185,7.45994781 25.2289977,8.68400999 26.484,8.953 C26.9583239,9.09677807 27.2557631,9.56630292 27.1831101,10.0565853 C27.1104571,10.5468677 26.6896362,10.91 26.194,10.91 L26.194,10.908 Z" fill="#434F26"></path>
								<path d="M25.529,17.034 C25.0457761,17.0335432 24.5652655,16.9617699 24.103,16.821 C23.7527328,16.7247486 23.4822063,16.4461254 23.3963232,16.0931729 C23.31044,15.7402203 23.4227085,15.3684525 23.6895938,15.1220309 C23.9564792,14.8756093 24.3360044,14.7932922 24.681,14.907 C25.8754238,15.3742165 27.2240535,14.7992814 27.714,13.614 C27.9602351,12.3576058 27.1554389,11.1352938 25.904,10.865 C25.5537328,10.7687486 25.2832063,10.4901254 25.1973232,10.1371729 C25.11144,9.78422034 25.2237085,9.41245251 25.4905938,9.16603089 C25.7574792,8.91960926 26.1370044,8.83729219 26.482,8.951 C28.792604,9.53744502 30.1973721,11.8781298 29.628,14.193 C29.0378732,15.9404542 27.3724075,17.0947816 25.529,17.034 Z" fill="#434F26"></path>
								<path d="M26.256,19.3 C25.7037153,19.3 25.256,18.8522847 25.256,18.3 L25.256,1.678 C25.256,1.12571525 25.7037153,0.678 26.256,0.678 C26.8082847,0.678 27.256,1.12571525 27.256,1.678 L27.256,18.3 C27.256,18.8522847 26.8082847,19.3 26.256,19.3 Z" fill="#434F26"></path>
							</g>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'sad' == $emoji ) {
				?>
				<svg width="56px" height="56px" viewBox="0 0 56 56" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<g fill="#F9BF44">
								<circle cx="28" cy="28" r="27.758"></circle>
							</g>
							<g transform="translate(10.000000, 14.000000)" fill="#382A12">
								<path d="M28.471,25.5800031 C28.0888299,25.5809521 27.7395364,25.364002 27.571,25.021 C25.7771486,21.3716073 22.0644444,19.0595882 17.998,19.0595882 C13.9315556,19.0595882 10.2188514,21.3716073 8.425,25.021 C8.18029169,25.514557 7.58249954,25.7172454 7.08807188,25.474301 C6.59364423,25.2313566 6.38882261,24.634292 6.63,24.139 C8.76034621,19.8057927 13.1689329,17.0606342 17.9975,17.0606342 C22.8260671,17.0606342 27.2346538,19.8057927 29.365,24.139 C29.5174937,24.4493469 29.4988339,24.8164525 29.315658,25.1097375 C29.1324821,25.4030225 28.8107872,25.5808625 28.465,25.5800031 L28.471,25.5800031 Z"></path>
								<path d="M6.475,15.555 C3.86701785,15.5658891 1.48347506,14.0814224 0.343,11.736 C0.183923092,11.4151546 0.208559673,11.0337374 0.407590715,10.736023 C0.606621757,10.4383086 0.949659301,10.269752 1.30694606,10.2941114 C1.66423282,10.3184707 1.98121843,10.5320268 2.138,10.854 C2.95122753,12.5069958 4.63329098,13.5540718 6.4755,13.5540718 C8.31770902,13.5540718 9.99977247,12.5069958 10.813,10.854 C11.0577083,10.360443 11.6555005,10.1577546 12.1499281,10.400699 C12.6443558,10.6436434 12.8491774,11.240708 12.608,11.736 C11.4673683,14.0817487 9.0833425,15.5662741 6.475,15.555 Z"></path>
								<path d="M4.8,7.96000002 C3.17526726,7.95845484 1.60493046,7.37445701 0.374,6.314 C-0.0457364099,5.95501491 -0.0949850874,5.32373641 0.264,4.904 C0.622985087,4.48426359 1.25426359,4.43501491 1.674,4.794 C3.07446968,5.99098829 5.03364678,6.28766155 6.72571748,5.55896887 C8.41778819,4.83027619 9.54840461,3.20297891 9.641,1.363 C9.67378117,0.814137898 10.1395868,0.392334876 10.689,0.414 C11.2403863,0.441485939 11.6651841,0.91059873 11.638,1.462 C11.5202429,4.06932154 9.91758524,6.37805055 7.516,7.4 C6.65819628,7.76950954 5.73400456,7.96000002 4.8,7.96000002 Z"></path>
								<path d="M29.929,7.96 C28.9943719,7.95902185 28.0697981,7.76709708 27.212,7.396 C24.8118299,6.37502084 23.2093996,4.06856304 23.09,1.463 C23.0623858,0.91071525 23.4877153,0.440614237 24.04,0.413 C24.5922847,0.385385763 25.0623858,0.81071525 25.09,1.363 C25.1830584,3.20297874 26.3139018,4.83008772 28.006027,5.55871242 C29.6981522,6.28733711 31.6573214,5.9907795 33.058,4.794 C33.4777364,4.43501491 34.1090149,4.48426359 34.468,4.904 C34.8269851,5.32373641 34.7777364,5.95501491 34.358,6.314 C33.1261496,7.37489692 31.5547172,7.95890633 29.929,7.96 Z"></path>
								<path d="M28.47,15.555 C25.8616575,15.5662741 23.4776317,14.0817487 22.337,11.736 C22.1779231,11.4151546 22.2025597,11.0337374 22.4015907,10.736023 C22.6006218,10.4383086 22.9436593,10.269752 23.3009461,10.2941114 C23.6582328,10.3184707 23.9752184,10.5320268 24.132,10.854 C24.9452275,12.5069958 26.627291,13.5540718 28.4695,13.5540718 C30.311709,13.5540718 31.9937725,12.5069958 32.807,10.854 C32.9637816,10.5320268 33.2807672,10.3184707 33.6380539,10.2941114 C33.9953407,10.269752 34.3383782,10.4383086 34.5374093,10.736023 C34.7364403,11.0337374 34.7610769,11.4151546 34.602,11.736 C33.4615249,14.0814224 31.0779822,15.5658891 28.47,15.555 Z"></path>
							</g>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'angry' == $emoji ) {
				?>
				<svg width="56px" height="56px" viewBox="0 0 56 56" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<g fill="#F6262F">
								<circle cx="28" cy="28" r="27.758"></circle>
							</g>
							<g transform="translate(7.000000, 20.000000)">
								<path d="M17.68,5.77 L2.27,0.63 C2.01868247,0.548860786 1.74547207,0.570430027 1.51,0.69 C1.27077365,0.801474781 1.0893574,1.00828931 1.01,1.26 C-0.577492169,6.03960723 2.00381892,11.2022294 6.78,12.8 C7.70479626,13.1114795 8.67415802,13.2702252 9.65,13.2700002 C13.5796178,13.2660319 17.0684979,10.755004 18.32,7.03 C18.4907915,6.50536184 18.2043985,5.94152578 17.68,5.77 L17.68,5.77 Z" fill="#A8111C"></path>
								<path d="M40.71,1.23 C40.6292601,0.977388472 40.4499726,0.768062019 40.2127697,0.649460572 C39.9755668,0.530859124 39.7005332,0.513025011 39.45,0.6 L24.06,5.81 C23.8083173,5.89915883 23.6006199,6.08178932 23.48,6.32 C23.3689933,6.55819607 23.3511566,6.8293138 23.43,7.08 C24.6908259,10.7837807 28.1675001,13.2757322 32.08,13.28 C35.0179555,13.2752082 37.7739318,11.8562779 39.4845848,9.46770678 C41.1952378,7.07913568 41.6513356,4.01307255 40.71,1.23 L40.71,1.23 Z" fill="#A8111C"></path>
								<path d="M31.471,19.5800031 C31.0888299,19.5809521 30.7395364,19.364002 30.571,19.021 C28.7771486,15.3716073 25.0644444,13.0595882 20.998,13.0595882 C16.9315556,13.0595882 13.2188514,15.3716073 11.425,19.021 C11.1802917,19.514557 10.5824995,19.7172454 10.0880719,19.474301 C9.59364423,19.2313566 9.38882261,18.634292 9.63,18.139 C11.7603462,13.8057927 16.1689329,11.0606342 20.9975,11.0606342 C25.8260671,11.0606342 30.2346538,13.8057927 32.365,18.139 C32.5174937,18.4493469 32.4988339,18.8164525 32.315658,19.1097375 C32.1324821,19.4030225 31.8107872,19.5808625 31.465,19.5800031 L31.471,19.5800031 Z" fill="#2D090E"></path>
							</g>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'haha' == $emoji ) {
				?>
				<svg width="56px" height="56px" viewBox="0 0 56 56" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<g fill="#F9BF44">
								<circle cx="28" cy="28" r="27.758"></circle>
							</g>
							<g transform="translate(2.000000, 19.000000)">
								<path d="M45.88,11.81 C45.5752966,11.8096575 45.2733779,11.7519877 44.99,11.64 C44.98,11.64 44.98,11.64 44.97,11.63 C44.7207822,11.5348033 44.4905178,11.3959674 44.29,11.22 C43.7695923,10.7763795 43.4608704,10.1335113 43.44,9.45 L43.44,9.44 L7.87,9.44 C7.86,9.47 7.85,9.49 7.84,9.52 L7.84,9.54 C7.84048876,9.62755756 7.83041603,9.71485453 7.81,9.8 C7.80908929,9.83423047 7.80232491,9.86805237 7.79,9.9 C7.78283362,9.96224256 7.7659625,10.0229786 7.74,10.08 C7.70928761,10.2134561 7.65872474,10.3415487 7.59,10.46 C7.56887526,10.5260128 7.53488833,10.5871892 7.49,10.64 C7.45254212,10.7103067 7.40904515,10.7772251 7.36,10.84 C7.31887917,10.9010149 7.27199759,10.9579425 7.22,11.01 C7.09676994,11.1511568 6.95556692,11.2755499 6.8,11.38 C6.39432138,11.6601087 5.91298683,11.8100898 5.42,11.81 C5.44245996,12.0245577 5.49988571,12.2339927 5.59,12.43 C5.79,12.87 6.01,13.31 6.23,13.73 C10.55,22.09 18.05,27.22 26.08,27.22 C34.08,27.22 41.57,22.12 45.9,13.81 C46.14,13.36 46.36,12.9 46.58,12.43 C46.6969101,12.1825078 46.7615874,11.9135866 46.77,11.64 C46.4866221,11.7519877 46.1847034,11.8096575 45.88,11.81 L45.88,11.81 Z" fill="#C15F1E"></path>
								<path d="M44.97,11.63 C44.7207822,11.5348033 44.4905178,11.3959674 44.29,11.22 C43.7695923,10.7763795 43.4608704,10.1335113 43.44,9.45 L7.85,9.45 C7.85158008,9.47377521 7.84817393,9.49761822 7.84,9.52 C7.83880546,9.64822564 7.82201545,9.77582974 7.79,9.9 C7.78283362,9.96224256 7.7659625,10.0229786 7.74,10.08 C7.70928761,10.2134561 7.65872474,10.3415487 7.59,10.46 C7.56887526,10.5260128 7.53488833,10.5871892 7.49,10.64 C7.45254212,10.7103067 7.40904515,10.7772251 7.36,10.84 C7.31887917,10.9010149 7.27199759,10.9579425 7.22,11.01 C7.09676994,11.1511568 6.95556692,11.2755499 6.8,11.38 C6.97,11.58 7.15,11.77 7.34,11.96 C7.62548905,12.2551545 7.92588111,12.5355204 8.24,12.8 C12.3,16.27 18.84,18.36 26.02,18.36 C32.99,18.36 39.38,16.39 43.45,13.08 C43.9859817,12.6462286 44.4905768,12.1750504 44.96,11.67 C44.98,11.66 44.99,11.65 44.99,11.64 C44.98,11.64 44.98,11.64 44.97,11.63 Z" fill="#FFFFFF"></path>
								<path d="M9.81,5.66 C9.68849143,5.23130905 9.29556571,4.93661476 8.85,4.93997114 L5.42,4.93997114 C2.97061713,4.93997114 0.985,6.92561713 0.985,9.375 C0.985,11.8243829 2.97061713,13.81 5.42,13.81 C5.69192864,13.8091316 5.96315536,13.7823438 6.23,13.73 C6.82339829,13.6227754 7.38842339,13.3947231 7.89,13.06 C8.01,12.98 8.12,12.89 8.24,12.8 C8.75430987,12.3708315 9.16459859,11.830618 9.44,11.22 C9.7036213,10.6667886 9.84353328,10.0627783 9.85,9.45 L9.85,5.94 C9.85223173,5.84837314 9.83870151,5.75704416 9.81,5.67 L9.81,5.66 Z" fill="#58B3DE"></path>
								<path d="M45.88,4.93998848 L42.44,4.93998848 C41.8877153,4.93998848 41.44,5.38771525 41.44,5.94 L41.44,9.45 C41.4465307,10.0627706 41.5864395,10.6667673 41.85,11.22 C41.867255,11.2694662 41.8907801,11.3165163 41.92,11.36 L42.51,11.36 C42.38,11.47 42.24,11.58 42.1,11.69 C42.4403138,12.2485186 42.9016534,12.7235276 43.45,13.08 C43.650985,13.2122026 43.8615718,13.3291952 44.08,13.43 C44.6474302,13.6792687 45.2602339,13.8086384 45.88,13.81 L45.9,13.81 C48.3493828,13.8044771 50.3305228,11.8143828 50.3250115,9.365 C50.3194771,6.91561716 48.3293828,4.93447719 45.88,4.93998848 L45.88,4.93998848 Z" fill="#58B3DE"></path>
								<path d="M41.523,6.013 C41.1406049,6.01376527 40.7912534,5.79639102 40.623,5.453 C39.8103127,3.79934616 38.1280612,2.75166197 36.2855,2.75166197 C34.4429388,2.75166197 32.7606873,3.79934616 31.948,5.453 C31.7953149,5.78160258 31.4768192,6.00190373 31.1154795,6.02884838 C30.7541398,6.05579302 30.406493,5.88516527 30.2067605,5.58284203 C30.007028,5.28051878 29.986461,4.89380299 30.153,4.572 C31.3014335,2.23331535 33.6800547,0.751422878 36.2855,0.751422878 C38.8909453,0.751422878 41.2695665,2.23331535 42.418,4.572 C42.5700218,4.88226015 42.5511175,5.2490154 42.3680015,5.54200095 C42.1848855,5.83498649 41.8635018,6.01269211 41.518,6.012 L41.523,6.013 Z" fill="#382A12"></path>
								<path d="M19.529,6.013 C19.1466049,6.01376527 18.7972534,5.79639102 18.629,5.453 C17.8163127,3.79934616 16.1340612,2.75166197 14.2915,2.75166197 C12.4489388,2.75166197 10.7666873,3.79934616 9.954,5.453 C9.80131488,5.78160258 9.48281917,6.00190373 9.12147946,6.02884838 C8.76013975,6.05579302 8.41249298,5.88516527 8.21276051,5.58284203 C8.01302805,5.28051878 7.992461,4.89380299 8.159,4.572 C9.3074335,2.23331535 11.6860547,0.751422878 14.2915,0.751422878 C16.8969453,0.751422878 19.2755665,2.23331535 20.424,4.572 C20.5760218,4.88226015 20.5571175,5.2490154 20.3740015,5.54200095 C20.1908855,5.83498649 19.8695018,6.01269211 19.524,6.012 L19.529,6.013 Z" fill="#382A12"></path>
							</g>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'unimpressed' == $emoji ) {
				?>
				<svg width="56px" height="56px" viewBox="0 0 56 56" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<g fill="#F9BF44">
								<circle cx="28" cy="28" r="27.758"></circle>
							</g>
							<g transform="translate(10.000000, 24.000000)" fill="#382A12">
								<path d="M11.868,11.422 C11.3754639,11.4205438 10.9573314,11.0606615 10.8825498,10.5738334 C10.8077682,10.0870052 11.0986089,9.6182177 11.568,9.469 C15.8525522,8.11929472 20.4484478,8.11929472 24.733,9.469 C25.2593273,9.6363423 25.5503422,10.1986726 25.3829999,10.725 C25.2156577,11.2513273 24.6533274,11.5423422 24.127,11.375 C20.2374123,10.1483975 16.0645877,10.1483975 12.175,11.375 C12.0757388,11.4065592 11.9721566,11.4224171 11.868,11.422 Z"></path>
								<path d="M11.25,2.338 L1.375,2.338 C0.82271525,2.338 0.375,1.89028475 0.375,1.338 C0.375,0.78571525 0.82271525,0.338 1.375,0.338 L11.25,0.338 C11.8022847,0.338 12.25,0.78571525 12.25,1.338 C12.25,1.89028475 11.8022847,2.338 11.25,2.338 Z"></path>
								<path d="M33.375,2.338 L23.5,2.338 C22.9477153,2.338 22.5,1.89028475 22.5,1.338 C22.5,0.78571525 22.9477153,0.338 23.5,0.338 L33.375,0.338 C33.9272847,0.338 34.375,0.78571525 34.375,1.338 C34.375,1.89028475 33.9272847,2.338 33.375,2.338 Z"></path>
							</g>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'gross' == $emoji ) {
				?>
				<svg width="56px" height="56px" viewBox="0 0 56 56" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<g fill="#F9BF44">
								<circle cx="28" cy="28" r="27.758"></circle>
							</g>
							<g transform="translate(1.000000, 0.000000)">
								<path d="M53.556,19.822 C53.016,20.282 52.456,20.722 51.856,21.152 C45.946,25.332 37.026,28.002 27.026,28.002 C17.026,28.002 8.106,25.332 2.196,21.152 C1.596,20.722 1.036,20.282 0.496,19.822 C4.08593055,8.18154816 14.8445501,0.240886641 27.026,0.240886641 C39.2074499,0.240886641 49.9660695,8.18154816 53.556,19.822 Z" fill="#80A148"></path>
								<ellipse fill="#434F26" cx="15.894" cy="25.865" rx="2.5" ry="2.87"></ellipse>
								<ellipse fill="#434F26" cx="37.889" cy="25.865" rx="2.5" ry="2.87"></ellipse>
								<path d="M12.48,24 C10.8552993,23.9982775 9.28502211,23.4143019 8.054,22.354 C7.78247814,22.1217774 7.65547089,21.7623396 7.72082066,21.4110835 C7.78617043,21.0598273 8.03394904,20.770117 8.37082068,20.6510835 C8.70769231,20.53205 9.08247815,20.6017773 9.354,20.834 C10.7548582,22.0318585 12.7150771,22.3286394 14.4077401,21.5991458 C16.100403,20.8696523 17.2307713,19.240909 17.322,17.4 C17.3398633,17.0427344 17.5469685,16.7221373 17.8653013,16.5589746 C18.183634,16.3958118 18.5648318,16.4148717 18.8653013,16.6089746 C19.1657707,16.8030774 19.3398633,17.1427344 19.322,17.5 C19.2034903,20.1065859 17.6009555,22.4143605 15.2,23.436 C14.3412743,23.8074974 13.4156387,23.9994307 12.48,24 Z" fill="#434F26"></path>
								<path d="M21.614,40.048002 C21.1512695,40.0489258 20.7483394,39.732262 20.6398646,39.2824248 C20.5313899,38.8325875 20.7457054,38.3670798 21.158,38.157 C22.7991869,37.3194316 23.8213432,35.6215542 23.793519,33.7792076 C23.7656948,31.9368609 22.6927316,30.2706253 21.027,29.483 C20.7038533,29.3304476 20.4866391,29.0170866 20.45718,28.6609571 C20.4277209,28.3048277 20.5904924,27.9600342 20.88418,27.7564571 C21.1778676,27.5528801 21.5578533,27.5214476 21.881,27.674 C24.2365074,28.7871033 25.754078,31.1428 25.7937982,33.7477638 C25.8335184,36.3527276 24.3884753,38.7535978 22.068,39.938 C21.9274732,40.0099948 21.7718953,40.0476898 21.614,40.048002 L21.614,40.048002 Z" fill="#382A12"></path>
								<path d="M32.327,40.048 C32.1691859,40.0479995 32.0136124,40.0106481 31.873,39.939 C29.5525247,38.7545978 28.1074816,36.3537276 28.1472018,33.7487638 C28.186922,31.1438 29.7044926,28.7881033 32.06,27.675 C32.3831467,27.5224476 32.7631324,27.5538801 33.05682,27.7574572 C33.3505076,27.9610342 33.5132791,28.3058277 33.48382,28.6619572 C33.4543609,29.0180866 33.2371467,29.3314476 32.914,29.484 C31.2482684,30.2716253 30.1753052,31.9378609 30.147481,33.7802076 C30.1196568,35.6225542 31.1418131,37.3204316 32.783,38.158 C33.1952946,38.3680798 33.4096101,38.8335875 33.3011354,39.2834248 C33.1926606,39.733262 32.7897305,40.0499258 32.327,40.049002 L32.327,40.048 Z" fill="#382A12"></path>
								<path d="M41.539,24 C40.6044877,23.9988887 39.6800065,23.8073234 38.822,23.437 C36.421365,22.4144249 34.8190869,20.1066312 34.7,17.5 C34.6821367,17.1427344 34.8562293,16.8030774 35.1566987,16.6089745 C35.4571682,16.4148717 35.838366,16.3958118 36.1566987,16.5589745 C36.4750315,16.7221373 36.6821367,17.0427344 36.7,17.4 C36.792238,19.2401587 37.9227187,20.8677895 39.6148607,21.5967253 C41.3070027,22.3256611 43.2663917,22.029075 44.667,20.832 C44.9385218,20.5997774 45.3133077,20.53005 45.6501793,20.6490835 C45.987051,20.768117 46.2348296,21.0578273 46.3001793,21.4090835 C46.3655291,21.7603396 46.2385219,22.1197774 45.967,22.352 C44.7357415,23.4134733 43.1646444,23.9981996 41.539,24 Z" fill="#434F26"></path>
								<rect fill="#382A12" x="23.794" y="32.778" width="6.354" height="2"></rect>
							</g>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'love' == $emoji ) {
				?>
				<svg width="56px" height="56px" viewBox="0 0 56 56" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<g fill="#F9BF44">
								<circle cx="28" cy="28" r="27.758"></circle>
							</g>
							<g transform="translate(5.000000, 19.000000)">
								<path d="M13.78,0.2 C12.1349794,0.229556441 10.6173725,1.09191869 9.75,2.49 C8.88262753,1.09191869 7.36502059,0.229556441 5.72,0.2 C2.94,0.2 0.68,2.74 0.68,5.86 C0.68,12.14 8.93,16.56 9.28,16.74 C9.42444375,16.8179674 9.5858591,16.8591798 9.75,16.86 C9.88705637,16.8575775 10.0225547,16.8304778 10.15,16.78 C10.5,16.62 18.82,12.94 18.82,5.86 C18.82,2.74 16.56,0.2 13.78,0.2 Z" fill="#F6262F"></path>
								<path d="M40.37,0.2 C38.724929,0.229372293 37.2072401,1.09178111 36.34,2.49 C35.4726275,1.09191869 33.9550206,0.229556441 32.31,0.2 C29.53,0.2 27.27,2.74 27.27,5.86 C27.27,12.14 35.52,16.56 35.87,16.74 C36.0144437,16.8179674 36.1758591,16.8591798 36.34,16.86 C36.4770564,16.8575775 36.6125547,16.8304778 36.74,16.78 C37.09,16.62 45.41,12.94 45.41,5.86 C45.41,2.74 43.15,0.2 40.37,0.2 Z" fill="#F6262F"></path>
								<path d="M15.65,15.438 C17.0508394,18.2965856 19.9566271,20.108553 23.14,20.108553 C26.3233729,20.108553 29.2291606,18.2965856 30.63,15.438 C30.7845875,15.1282705 30.7656144,14.7601933 30.58,14.468 C30.3968845,14.1750145 30.0755015,13.9973086 29.73,13.997998 L16.55,13.997998 C16.2044985,13.9973086 15.8831155,14.1750145 15.7,14.468 C15.5143856,14.7601933 15.4954125,15.1282705 15.65,15.438 L15.65,15.438 Z" fill="#C15F1E"></path>
							</g>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'yikes' == $emoji ) {
				?>
				<svg width="56px" height="56px" viewBox="0 0 56 56" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<g fill="#F9BF44">
								<circle cx="28" cy="28" r="27.758"></circle>
							</g>
							<g transform="translate(10.000000, 21.000000)">
								<ellipse fill="#F6262F" cx="6.5" cy="16.5" rx="6.5" ry="2.5"></ellipse>
								<circle fill="#FFFFFF" cx="7.003" cy="6.992" r="6.622"></circle>
								<ellipse fill="#F6262F" cx="29.5" cy="16.5" rx="6.5" ry="2.5"></ellipse>
								<circle fill="#FFFFFF" cx="28.998" cy="6.992" r="6.622"></circle>
								<ellipse fill="#382A12" cx="7.003" cy="7.151" rx="1.521" ry="1.746"></ellipse>
								<ellipse fill="#382A12" cx="28.997" cy="7.151" rx="1.521" ry="1.746"></ellipse>
								<path d="M21.917,16.7 L14.083,16.7 C13.5307153,16.7 13.083,16.2522847 13.083,15.7 C13.083,15.1477153 13.5307153,14.7 14.083,14.7 L21.916,14.7 C22.4682847,14.7 22.916,15.1477153 22.916,15.7 C22.916,16.2522847 22.4682847,16.7 21.916,16.7 L21.917,16.7 Z" fill="#382A12"></path>
							</g>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'cool' == $emoji ) {
				?>
				<svg width="56px" height="56px" viewBox="0 0 56 56" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<g fill="#F9BF44">
								<circle cx="28" cy="28" r="27.758"></circle>
							</g>
							<g transform="translate(10.000000, 22.000000)">
								<path d="M23.762,5.92500201 C23.4164982,5.92569211 23.0951145,5.74798649 22.9119985,5.45500095 C22.7288825,5.1620154 22.7099782,4.79526015 22.862,4.485 C24.0109747,2.14697419 26.3894074,0.665690885 28.9945,0.665690885 C31.5995926,0.665690885 33.9780253,2.14697419 35.127,4.485 C35.3681774,4.98029199 35.1633558,5.57735659 34.6689281,5.82030099 C34.1745005,6.06324538 33.5767083,5.86055702 33.332,5.367 C32.5187725,3.71400422 30.836709,2.66692824 28.9945,2.66692824 C27.152291,2.66692824 25.4702275,3.71400422 24.657,5.367 C24.4889772,5.70799505 24.142143,5.92423361 23.762,5.92500201 Z" fill="#382A12"></path>
								<path d="M12.238,5.92500201 C11.8556049,5.92576527 11.5062534,5.70839102 11.338,5.365 C10.5247725,3.71200422 8.84270902,2.66492824 7.0005,2.66492824 C5.15829098,2.66492824 3.47622753,3.71200422 2.663,5.365 C2.41829169,5.85855702 1.82049954,6.06124538 1.32607188,5.81830099 C0.831644228,5.57535659 0.626822612,4.97829199 0.868,4.483 C2.01697465,2.14497419 4.3954074,0.663690885 7.0005,0.663690885 C9.6055926,0.663690885 11.9840253,2.14497419 13.133,4.483 C13.2850218,4.79326015 13.2661175,5.1600154 13.0830015,5.45300095 C12.8998855,5.74598649 12.5785018,5.92369211 12.233,5.923 L12.238,5.92500201 Z" fill="#382A12"></path>
								<path d="M34.9,9.43 C34.7226722,9.13596015 34.4033617,8.95729831 34.06,8.95996979 L1.94,8.95996979 C1.59627795,8.96274373 1.27805526,9.14182982 1.09733956,9.43422375 C0.916623861,9.72661769 0.898746527,10.0913339 1.05,10.4 C4.22833963,16.8590282 10.8013274,20.9502937 18,20.9502937 C25.1986726,20.9502937 31.7716604,16.8590282 34.95,10.4 C35.1095533,10.091325 35.0904455,9.72063379 34.9,9.43 L34.9,9.43 Z" fill="#C15F1E"></path>
							</g>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'confused' == $emoji ) {
				?>
				<svg width="56px" height="56px" viewBox="0 0 56 56" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<g fill="#F9BF44">
								<circle cx="28" cy="28" r="27.758"></circle>
							</g>
							<g transform="translate(10.000000, 13.000000)" fill="#382A12">
								<path d="M25.022,21.589 C24.9201905,21.5886962 24.8190244,21.5728468 24.722,21.542 C20.8323625,20.3157211 16.6596375,20.3157211 12.77,21.542 C12.4275371,21.6571005 12.0496185,21.5785277 11.7814133,21.3364637 C11.5132082,21.0943997 11.3964265,20.7264891 11.4759274,20.3740567 C11.5554282,20.0216243 11.8188481,19.7394787 12.165,19.636 C16.4488549,18.2861979 21.0441451,18.2861979 25.328,19.636 C25.799048,19.7840328 26.0915416,20.2537106 26.0166119,20.7417531 C25.9416821,21.2297956 25.521761,21.5900955 25.028,21.59 L25.022,21.589 Z"></path>
								<path d="M23.669,10.0000252 C23.5165793,10.0010889 23.3659775,9.96686125 23.229,9.9 C22.9909275,9.78295023 22.8091222,9.57609702 22.7236,9.32496931 C22.6380778,9.0738416 22.6558482,8.79902234 22.773,8.561 C23.9186642,6.21890968 26.3037518,4.73920727 28.911,4.753 C29.5673057,4.75184433 30.2202398,4.84685332 30.849,5.035 C32.5985875,5.55470644 34.0681168,6.75171398 34.931,8.36 C35.1102507,8.67568048 35.1043436,9.06371086 34.9155667,9.37378872 C34.7267898,9.68386657 34.3847958,9.86728562 34.022055,9.85299904 C33.6593142,9.83871245 33.3328051,9.62896434 33.169,9.305 C32.5582336,8.16685626 31.5182014,7.31978259 30.28,6.952 C29.8355868,6.81862443 29.3739952,6.75123878 28.91,6.752 C27.0653163,6.74023783 25.3771026,7.7866738 24.567,9.444 C24.3979356,9.78518697 24.0497765,10.000751 23.669,10.0000252 Z"></path>
								<path d="M1.679,5.58302519 C1.52657929,5.58408893 1.37597749,5.54986125 1.239,5.483 C1.00092748,5.36595023 0.819122197,5.15909702 0.733599991,4.90796931 C0.648077784,4.6568416 0.665848229,4.38202234 0.783,4.144 C1.91773357,1.85092195 4.23763782,0.383129809 6.79575165,0.339761243 C9.35386548,0.296392677 11.7221902,1.6847037 12.934,3.938 C13.1924693,4.42621972 13.0062197,5.03153074 12.518,5.29 C12.0297803,5.54846926 11.4244693,5.36221972 11.166,4.874 C10.3190224,3.31257359 8.68634872,2.33895381 6.91,2.336 C5.06891759,2.32808657 3.38553249,3.37393764 2.577,5.028 C2.40765466,5.36879825 2.05955276,5.58393918 1.679,5.58302519 L1.679,5.58302519 Z"></path>
								<ellipse cx="7.746" cy="12.745" rx="2.5" ry="2.87"></ellipse>
								<ellipse cx="29.741" cy="12.745" rx="2.5" ry="2.87"></ellipse>
							</g>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'sleepy' == $emoji ) {
				?>
				<svg width="56px" height="56px" viewBox="0 0 56 56" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<g fill="#F9BF44">
								<circle cx="28" cy="28" r="27.758"></circle>
							</g>
							<g transform="translate(10.000000, 3.000000)">
								<path d="M18,27.3 C15.94,27.3 14.25,29.39 14.25,31.96 C14.25,34.53 15.94,36.63 18,36.63 C20.06,36.63 21.75,34.54 21.75,31.96 C21.75,29.38 20.07,27.3 18,27.3 Z" fill="#C15F1E"></path>
								<path d="M6.867,26.586 C4.2586575,26.5972741 1.87463172,25.1127487 0.734,22.767 C0.504773626,22.2736685 0.71194479,21.6875937 1.2002829,21.4479135 C1.688621,21.2082334 2.27897478,21.4028768 2.529,21.886 C3.34256016,23.5388952 5.02473432,24.585823 6.867,24.585823 C8.70926568,24.585823 10.3914398,23.5388952 11.205,21.886 C11.4550252,21.4028768 12.045379,21.2082334 12.5337171,21.4479135 C13.0220552,21.6875937 13.2292264,22.2736685 13,22.767 C11.8593683,25.1127487 9.4753425,26.5972741 6.867,26.586 Z" fill="#382A12"></path>
								<path d="M28.861,26.586 C26.2530178,26.5968891 23.8694751,25.1124224 22.729,22.767 C22.4997736,22.2736685 22.7069448,21.6875937 23.1952829,21.4479135 C23.683621,21.2082334 24.2739748,21.4028768 24.524,21.886 C25.3372275,23.5389958 27.019291,24.5860718 28.8615,24.5860718 C30.703709,24.5860718 32.3857725,23.5389958 33.199,21.886 C33.4490252,21.4028768 34.039379,21.2082334 34.5277171,21.4479135 C35.0160552,21.6875937 35.2232264,22.2736685 34.994,22.767 C33.8533683,25.1127487 31.4693425,26.5972741 28.861,26.586 Z" fill="#382A12"></path>
								<path d="M34.146,15.75 L29.523,15.75 C29.1256503,15.75 28.7660311,15.5146408 28.6068682,15.1505612 C28.4477054,14.7864815 28.5191995,14.3627096 28.789,14.071 L31.86,10.75 L29.523,10.75 C28.9707153,10.75 28.523,10.3022847 28.523,9.75 C28.523,9.19771525 28.9707153,8.75 29.523,8.75 L34.146,8.75 C34.5433497,8.75 34.9029689,8.98535918 35.0621318,9.34943883 C35.2212946,9.71351847 35.1498005,10.1372904 34.88,10.429 L31.81,13.75 L34.147,13.75 C34.6992847,13.75 35.147,14.1977153 35.147,14.75 C35.147,15.3022847 34.6992847,15.75 34.147,15.75 L34.146,15.75 Z" fill="#382A12"></path>
								<path d="M44.325,10.164 L37.388,10.164 C36.9386897,10.1632445 36.5322779,9.89705304 36.3520492,9.48547318 C36.1718206,9.07389332 36.2518321,8.59469962 36.556,8.264 L41.736,2.664 L37.388,2.664 C36.7622614,2.664 36.255,2.15673862 36.255,1.531 C36.255,0.905261378 36.7622614,0.398 37.388,0.398 L44.326,0.398 C44.7753103,0.39875546 45.1817221,0.66494696 45.3619508,1.07652682 C45.5421794,1.48810668 45.4621679,1.96730038 45.158,2.298 L39.978,7.898 L44.326,7.898 C44.9517386,7.898 45.459,8.4052614 45.459,9.031 C45.459,9.6567386 44.9517386,10.164 44.326,10.164 L44.325,10.164 Z" fill="#382A12"></path>
							</g>
						</g>
					</g>
				</svg>
				<?php
			}
		} elseif ( 2 == $style ) {
			if ( 'happy' == $emoji ) {
				?>
				<svg width="24px" height="24px" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<path d="M12,0 C5.3833008,0 0,5.3833008 0,12 C0,18.6166992 5.3833008,24 12,24 C18.6166992,24 24,18.6166992 24,12 C24,5.3833008 18.6166992,0 12,0 Z" fill="#303C42"></path>
							<path d="M12,23 C5.9345703,23 1,18.0654297 1,12 C1,5.9345703 5.9345703,1 12,1 C18.0654297,1 23,5.9345703 23,12 C23,18.0654297 18.0654297,23 12,23 Z" fill="#FED600"></path>
							<path d="M19.119751,3.630249 C20.7561646,5.5509644 21.75,8.0349121 21.75,10.75 C21.75,16.8154297 16.8154297,21.75 10.75,21.75 C8.0349121,21.75 5.5509644,20.7561646 3.630249,19.119751 C5.6494751,21.4898682 8.6496582,23 12,23 C18.0654297,23 23,18.0654297 23,12 C23,8.6496582 21.4898682,5.6494751 19.119751,3.630249 Z" fill="#010101" opacity="0.1"></path>
							<path d="M18.4399414,14.0209961 C18.1689453,13.9560547 17.9013672,14.1230469 17.8378906,14.3916016 C17.1933594,17.1049805 14.7929688,19 12,19 C9.2036133,19 6.8022461,17.1020508 6.1606445,14.3852539 C6.0966797,14.1157226 5.8256836,13.9521484 5.559082,14.0131836 C5.290039,14.0766602 5.1235351,14.3461914 5.1870117,14.6147461 C5.9360352,17.7856445 8.737793,20 12,20 C15.2583008,20 18.059082,17.7890625 18.8105469,14.6230469 C18.8745117,14.3540039 18.7084961,14.0844727 18.4399414,14.0209961 Z" fill="#303C42"></path>
							<circle fill="#303C42" cx="8" cy="9" r="1"></circle>
							<circle fill="#303C42" cx="16" cy="9" r="1"></circle>
							<path d="M12,0 C5.3833008,0 0,5.3833008 0,12 C0,18.6166992 5.3833008,24 12,24 C18.6166992,24 24,18.6166992 24,12 C24,5.3833008 18.6166992,0 12,0 Z" fill="url(#linearGradient-1)"></path>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'haha' == $emoji ) {
				?>
				<svg width="24px" height="24px" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<path d="M12,0 C5.3833008,0 0,5.3828125 0,12 C0,18.6171875 5.3833008,24 12,24 C18.6166992,24 24,18.6171875 24,12 C24,5.3828125 18.6166992,0 12,0 Z" fill="#303C42"></path>
							<path d="M6.4892578,3.0107422 C6.6420898,3.0146485 7.0776367,3.2226563 7.5629883,3.5107422 C7.0786133,3.7988281 6.6430664,4.0058594 6.4897461,4.0107422 C6.2138672,4.0107422 5.9897461,3.7861328 5.9897461,3.5107422 C5.9897461,3.2353516 6.2138672,3.0107422 6.4892578,3.0107422 Z" fill="#BDDDF4"></path>
							<path d="M12,23 C5.9345703,23 1,18.0654297 1,12 C1,8.5957031 2.5551758,5.5483398 4.9915771,3.5290527 C5.0016479,4.3475952 5.6688842,5.0107422 6.489746,5.0107422 C7.1289062,5.0107422 8.2998046,4.2490234 8.7739257,3.921875 C8.9091796,3.8291016 8.989746,3.6748047 8.989746,3.5107422 C8.989746,3.3466797 8.9091797,3.1923828 8.7739258,3.0996094 C8.4297485,2.8621216 7.7196045,2.3985596 7.1110229,2.1607056 C8.5860596,1.4246826 10.2425537,1 12,1 C18.0654297,1 23,5.9345703 23,12 C23,13.7572021 22.5753784,15.4135132 21.8395386,16.8884277 C21.6016846,16.2798462 21.1386109,15.5702514 20.9008789,15.2265625 C20.7143555,14.9570312 20.2651367,14.9570312 20.0786133,15.2265625 C19.7509766,15.7001953 18.9897461,16.8710938 18.9897461,17.5107422 C18.9897461,18.3313599 19.6524048,18.99823 20.4705811,19.0087891 C18.4512939,21.4449463 15.4041138,23 12,23 Z" fill="#FED600"></path>
							<path d="M20.4897461,18.0107422 C20.2138672,18.0107422 19.9897461,17.7861328 19.9897461,17.5117188 C19.9936524,17.3583985 20.2016602,16.9228516 20.4897461,16.4375 C20.777832,16.921875 20.9858399,17.3583984 20.9897461,17.5117188 C20.9892578,17.7871094 20.7651367,18.0107422 20.4897461,18.0107422 Z" fill="#BDDDF4"></path>
							<path d="M6.3432617,5.6357422 C6.1479492,5.4404297 5.8315429,5.4404297 5.6362304,5.6357422 C3.9360352,7.3359375 3,9.5957031 3,12 C3,14.4042969 3.9360352,16.6640625 5.6362305,18.3642578 C7.390625,20.1191406 9.6953125,20.9960938 12,20.9960938 C14.3046875,20.9960938 16.609375,20.1191407 18.3637695,18.3642579 C18.559082,18.1689454 18.559082,17.8525391 18.3637695,17.6572266 L6.3432617,5.6357422 Z" fill="#303C42"></path>
							<path d="M12,20 C9.8632812,20 7.8540039,19.1679687 6.3432617,17.6572266 C4.8320313,16.1464844 4,14.1367188 4,12 C4,10.0302734 4.706543,8.1699219 6.0004883,6.7070312 L17.2924805,18 C15.8300781,19.2939453 13.9692383,20 12,20 Z" fill="#B72025"></path>
							<path d="M4.8537598,12.8537598 C4.8537598,10.8840332 5.5602417,9.0237427 6.854187,7.5608521 L6.0004883,6.7070313 C4.706543,8.1699219 4,10.0302734 4,12 C4,14.1367188 4.8320313,16.1464844 6.3432617,17.6572266 C6.4865722,17.8005371 6.6384277,17.9318238 6.7904053,18.0628052 C5.5410156,16.612793 4.8537598,14.7872925 4.8537598,12.8537598 Z" fill="#010101" opacity="0.1"></path>
							<path d="M10.2763672,5.9472656 L14.2763672,7.9472656 C14.3476563,7.9824219 14.4238281,8 14.5,8 C14.6293945,8 14.7573242,7.9492187 14.8535156,7.8535156 C15.0058594,7.7011718 15.043457,7.46875 14.9472656,7.2763672 L12.9472656,3.2763672 C12.8237304,3.0302734 12.5229492,2.9277344 12.2763672,3.0527344 C12.0292969,3.1767578 11.9291992,3.4765625 12.0527344,3.7236328 L13.381836,6.3818359 L10.7236329,5.0527343 C10.4760743,4.9277343 10.1767579,5.0302734 10.0527345,5.2763671 C9.9291992,5.5234375 10.0292969,5.8232422 10.2763672,5.9472656 Z" fill="#303C42"></path>
							<path d="M18.9472656,13.2763672 L17.618164,10.6181641 L20.2763671,11.9472657 C20.5234374,12.0712891 20.8232421,11.9697266 20.9472655,11.7236329 C21.0708007,11.4765626 20.970703,11.1767579 20.7236327,11.0527345 L16.7236327,9.0527345 C16.5307616,8.9570314 16.2993163,8.9941407 16.1464843,9.1464845 C15.9941405,9.2988283 15.9565429,9.5312501 16.0527343,9.7236329 L18.0527343,13.7236329 C18.140625,13.8984375 18.3168945,14 18.5004883,14 C18.5756836,14 18.6518555,13.9833984 18.7236328,13.9472656 C18.9707031,13.8232422 19.0708008,13.5234375 18.9472656,13.2763672 Z" fill="#303C42"></path>
							<g transform="translate(3.000000, 3.000000)" fill="#010101" opacity="0.1">
								<path d="M19.8789063,7.4572754 C19.8423462,7.1987305 19.8052369,6.9403687 19.7509156,6.6879883 C19.7210084,6.5489502 19.6801148,6.4141846 19.6450196,6.2771607 C19.5852662,6.0444336 19.5250245,5.8118897 19.4506837,5.5853882 C19.4069215,5.4519043 19.3547364,5.3223877 19.3060914,5.1911621 C19.2226563,4.9666748 19.136963,4.7432861 19.0394898,4.526001 C18.9852295,4.4047241 18.9251099,4.2867432 18.8666382,4.1677857 C18.7573242,3.946106 18.6437988,3.7271119 18.5202637,3.5141602 C18.4598999,3.4098511 18.3963623,3.3078003 18.3327027,3.2056885 C18.1946412,2.9846192 18.0501099,2.7679444 17.8970948,2.5577393 C17.8349,2.472107 17.7714844,2.3874512 17.7069093,2.3036499 C17.5374757,2.0842895 17.3599855,1.8716431 17.1748048,1.6658325 C17.1147462,1.5988769 17.0550538,1.5316162 16.9933473,1.4661865 C16.7905885,1.2514648 16.5784913,1.0459594 16.3593141,0.8480224 C16.3311769,0.8226318 16.303528,0.7966918 16.2751466,0.7715453 C17.9661865,2.7056885 19,5.2290039 19,8 C19,9.5866699 18.6573486,11.0910645 18.0527344,12.4535522 C18.3023682,12.8309936 18.643982,13.3880615 18.8395386,13.8884277 C19.0211182,13.5244751 19.1829224,13.1491699 19.3248902,12.7643432 C19.3286133,12.7541503 19.3323365,12.7440185 19.3360596,12.7338256 C19.4644165,12.3828124 19.571045,12.0217284 19.6637574,11.6553954 C19.6779176,11.5986327 19.6941529,11.5426635 19.7073975,11.4855346 C19.7844239,11.1590575 19.8409424,10.8252563 19.8877564,10.4882812 C19.8990479,10.4050903 19.9162598,10.3237304 19.9256592,10.2399291 C19.9725952,9.8328247 20,9.4197388 20,9 C20,8.6034546 19.9765625,8.2124634 19.9354858,7.8269653 C19.9221191,7.7019653 19.8963623,7.5809937 19.8789063,7.4572754 Z"></path>
								<path d="M10.5465698,19.8788452 C10.8237915,19.8395386 11.0997925,19.7967529 11.3699951,19.7371216 C11.4963989,19.7093506 11.6193237,19.6730347 11.7440796,19.6409302 C12.0007935,19.574646 12.2557984,19.5039063 12.5049439,19.4197998 C12.6230469,19.3800659 12.7387696,19.3353271 12.8550416,19.291687 C13.1077271,19.1966553 13.3569337,19.0947876 13.6004029,18.9820557 C13.7023316,18.9349976 13.8031007,18.8861695 13.9032593,18.8361206 C14.1588745,18.7080688 14.4086914,18.5705566 14.6525269,18.423706 C14.7322998,18.3757324 14.8126832,18.3287353 14.8911133,18.2788085 C15.1571655,18.1091918 15.4147949,17.9277953 15.6647339,17.7366332 C15.7142944,17.6987914 15.765564,17.66333 15.8143921,17.6246947 C16.4206543,17.1445311 16.9772339,16.6040038 17.4705811,16.0087889 C16.9401246,16.001953 16.4785157,15.7169798 16.2170411,15.2952879 C14.2020874,17.5631104 11.2722778,19 8,19 C5.2290039,19 2.7056885,17.9661865 0.7715454,16.2751465 C0.7966919,16.3035278 0.8226318,16.3311768 0.8480225,16.359314 C1.0459595,16.5784912 1.2514649,16.7905884 1.4661866,16.9933472 C1.5316163,17.0550537 1.598877,17.1147461 1.6658326,17.1748047 C1.8716431,17.3599854 2.0842896,17.5374756 2.30365,17.7069092 C2.3874513,17.7714844 2.472107,17.8348999 2.5577394,17.8970947 C2.7679445,18.0501098 2.9846193,18.1946411 3.2056886,18.3327026 C3.3078004,18.3963623 3.4098512,18.4598999 3.5141603,18.5202636 C3.727112,18.6437988 3.9461061,18.7573241 4.1677858,18.8666381 C4.2867433,18.9251098 4.4047243,18.9852294 4.5260011,19.0394897 C4.7432863,19.1369628 4.9666749,19.2226562 5.1911622,19.3060913 C5.3223878,19.3547363 5.4519044,19.4069214 5.5853883,19.4506836 C5.8118898,19.5250244 6.0444337,19.5852661 6.2771608,19.6450195 C6.4141847,19.6801147 6.5489504,19.7210083 6.6879884,19.7509155 C6.9403688,19.8052368 7.1987306,19.8423462 7.4572755,19.8789062 C7.5809938,19.8963623 7.7019654,19.9221191 7.8269654,19.9354858 C8.2124634,19.9765625 8.6034546,20 9,20 C9.4057617,20 9.805603,19.9747314 10.2000732,19.9317017 C10.3171387,19.9190063 10.430603,19.8952026 10.5465698,19.8788452 Z"></path>
							</g>
							<path d="M12,0 C5.3833008,0 0,5.3828125 0,12 C0,18.6171875 5.3833008,24 12,24 C18.6166992,24 24,18.6171875 24,12 C24,5.3828125 18.6166992,0 12,0 Z" fill="url(#linearGradient-1)"></path>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'angry' == $emoji ) {
				?>
				<svg width="24px" height="24px" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<defs>
						<linearGradient x1="4.68682292%" y1="28.8701175%" x2="95.3131754%" y2="71.1298783%">
							<stop stop-color="#FFFFFF" stop-opacity="0.2" offset="0%"></stop>
							<stop stop-color="#FFFFFF" stop-opacity="0" offset="100%"></stop>
						</linearGradient>
					</defs>
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<path d="M12,0 C5.3833008,0 0,5.3828125 0,12 C0,18.6171875 5.3833008,24 12,24 C18.6166992,24 24,18.6171875 24,12 C24,5.3828125 18.6166992,0 12,0 Z" fill="#303C42"></path>
							<path d="M12,23 C5.9345703,23 1,18.0654297 1,12 C1,5.9345703 5.9345703,1 12,1 C13.6971436,1 15.2993164,1.397644 16.736084,2.0869751 C16.7058106,2.1062622 16.6729126,2.1200562 16.6464844,2.1464844 L16,2.7929688 L15.3535156,2.1464844 C15.1582031,1.9511719 14.8417968,1.9511719 14.6464843,2.1464844 C14.4511718,2.3417969 14.4511718,2.6582032 14.6464843,2.8535157 L15.6464843,3.8535157 C15.7441406,3.9511719 15.8720703,4 16,4 C16.1279297,4 16.2558594,3.9511719 16.3535156,3.8535156 L17.3535156,2.8535156 C17.4545898,2.7524414 17.5009765,2.6191406 17.4974365,2.4867553 C20.7811279,4.3919678 23,7.9380493 23,12 C23,18.0654297 18.0654297,23 12,23 Z" fill="#E53A35"></path>
							<path d="M19.1216431,3.6641235 C20.7502441,5.5797119 21.75,8.0437012 21.75,10.75 C21.75,16.8154297 16.8154297,21.75 10.75,21.75 C8.0349121,21.75 5.5509644,20.7561646 3.630249,19.119751 C5.6494751,21.4898682 8.6496582,23 12,23 C18.0654297,23 23,18.0654297 23,12 C23,8.6577759 21.4831543,5.6811523 19.1216431,3.6641235 Z" fill="#010101" opacity="0.1"></path>
							<path d="M6,11 C6,12.1025391 6.8969727,13 8,13 C9.1030273,13 10,12.1025391 10,11 C10,10.9578857 9.9901123,10.9185181 9.9875488,10.8770752 L10.2763672,11.0214844 C10.3481445,11.0576172 10.4243164,11.0742188 10.4995117,11.0742188 C10.6831055,11.0742188 10.859375,10.9726563 10.9472656,10.7978516 C11.0708008,10.5507813 10.9707031,10.2509766 10.7236328,10.1269532 L6.7236328,8.1269532 C6.4770508,8.0029298 6.1762695,8.1044923 6.0527344,8.350586 C5.9291992,8.5976563 6.0292969,8.897461 6.2763672,9.0214844 L6.899292,9.3329468 C6.3583374,9.6913452 6,10.3040771 6,11 Z" fill="#303C42"></path>
							<circle fill="#BDDDF4" cx="8" cy="11" r="1"></circle>
							<path d="M8.4083862,10.0919189 C8.4649658,10.2171631 8.5,10.3537598 8.5,10.5 C8.5,11.0517578 8.0512695,11.5 7.5,11.5 C7.3536987,11.5 7.21698,11.4647827 7.0916138,11.4080811 C7.2485352,11.7554932 7.5947876,12 8,12 C8.5512695,12 9,11.5517578 9,11 C9,10.5946655 8.7554321,10.2489014 8.4083862,10.0919189 Z" fill="#010101" opacity="0.1"></path>
							<path d="M17.100708,9.3329468 L17.7236328,9.0214844 C17.9707031,8.897461 18.0708008,8.5976563 17.9472656,8.350586 C17.8232422,8.1044922 17.5224609,8.0029297 17.2763672,8.1269532 L13.2763672,10.1269532 C13.0292969,10.2509766 12.9291992,10.5507813 13.0527344,10.7978516 C13.140625,10.9726563 13.3168946,11.0742188 13.5004883,11.0742188 C13.5756836,11.0742188 13.6518555,11.0576172 13.7236328,11.0214844 L14.0124512,10.8770752 C14.0098877,10.9185181 14,10.9578857 14,11 C14,12.1025391 14.8969727,13 16,13 C17.1030273,13 18,12.1025391 18,11 C18,10.3040771 17.6416626,9.6913452 17.100708,9.3329468 Z" fill="#303C42"></path>
							<circle fill="#BDDDF4" cx="16" cy="11" r="1"></circle>
							<path d="M12,15 C11.9990234,15 11.9980469,15 11.9970703,15 C7.7973633,15 6.1674805,17.1103516 6.1000976,17.2001953 C5.9350585,17.4199219 5.9794921,17.7304687 6.1982421,17.8964844 C6.4174804,18.0625 6.7304687,18.0205078 6.8979491,17.8027344 C6.9545898,17.7294922 8.3320313,16 11.9970703,16 C11.9980469,16 11.9990234,16 12,16 C15.6669922,16.0009766 17.0454102,17.7294922 17.1000977,17.7998047 C17.1982422,17.9306641 17.3486328,18 17.5004883,18 C17.6049805,18 17.709961,17.9677734 17.800293,17.9003906 C18.0209961,17.734375 18.0654297,17.4208984 17.8999024,17.2001953 C17.8325195,17.1103516 16.2016602,15.0009766 12,15 Z" fill="#303C42"></path>
							<path d="M14.6464844,7.8535156 C14.8417969,8.0488281 15.1582032,8.0488281 15.3535157,7.8535156 L16,7.2070313 L16.6464844,7.8535157 C16.7441406,7.9511719 16.8720703,7.99999993 17,7.99999993 C17.1279297,7.99999993 17.2558594,7.9511719 17.3535156,7.8535156 C17.5488281,7.6582031 17.5488281,7.3417968 17.3535156,7.1464843 L16.3535156,6.1464843 C16.1582031,5.9511718 15.8417968,5.9511718 15.6464843,6.1464843 L14.6464843,7.1464843 C14.4511719,7.3417969 14.4511719,7.6582031 14.6464844,7.8535156 Z" fill="#303C42"></path>
							<path d="M13.1464844,6.3535156 C13.2441406,6.4511719 13.3720703,6.49999993 13.4999999,6.49999993 C13.6279297,6.49999993 13.7558594,6.4511719 13.8535156,6.3535156 L14.8535156,5.3535156 C15.0488281,5.1582031 15.0488281,4.8417968 14.8535156,4.6464843 L13.8535156,3.6464843 C13.6582031,3.4511718 13.3417968,3.4511718 13.1464843,3.6464843 C12.9511718,3.8417968 12.9511718,4.1582031 13.1464843,4.3535156 L13.7929688,4.99999993 L13.1464844,5.6464844 C12.9511719,5.8417969 12.9511719,6.1582031 13.1464844,6.3535156 Z" fill="#303C42"></path>
							<path d="M18.8535156,3.6464844 C18.6582031,3.4511719 18.3417968,3.4511719 18.1464843,3.6464844 L17.1464843,4.6464844 C16.9511718,4.8417969 16.9511718,5.1582032 17.1464843,5.3535157 L18.1464843,6.3535157 C18.2441406,6.4511719 18.3720703,6.50000003 18.4999999,6.50000003 C18.6279297,6.50000003 18.7558594,6.4511719 18.8535156,6.3535156 C19.0488281,6.1582031 19.0488281,5.8417968 18.8535156,5.6464843 L18.2070313,5.00000003 L18.8535157,4.3535156 C19.0488281,4.1582031 19.0488281,3.8417969 18.8535156,3.6464844 Z" fill="#303C42"></path>
							<path d="M16.4083862,10.0919189 C16.4649658,10.2171631 16.5,10.3537598 16.5,10.5 C16.5,11.0517578 16.0512695,11.5 15.5,11.5 C15.3536987,11.5 15.21698,11.4647827 15.0916138,11.4080811 C15.2485352,11.7554932 15.5947876,12 16,12 C16.5512695,12 17,11.5517578 17,11 C17,10.5946655 16.7554321,10.2489014 16.4083862,10.0919189 Z" fill="#010101" opacity="0.1"></path>
							<path d="M12,0 C5.3833008,0 0,5.3828125 0,12 C0,18.6171875 5.3833008,24 12,24 C18.6166992,24 24,18.6171875 24,12 C24,5.3828125 18.6166992,0 12,0 Z" fill="url(#linearGradient-1)"></path>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'cry' == $emoji ) {
				?>
				<svg width="24px" height="24px" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<defs>
						<linearGradient x1="2.81755208%" y1="32.878955%" x2="95.9817408%" y2="76.3221262%">
							<stop stop-color="#FFFFFF" stop-opacity="0.2" offset="0%"></stop>
							<stop stop-color="#FFFFFF" stop-opacity="0" offset="100%"></stop>
						</linearGradient>
					</defs>
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g )" fill-rule="nonzero">
							<path d="M20.0985718,20.8317871 C22.5758057,18.5588989 24,15.3775024 24,12 C24,5.3833008 18.6171875,0 12,0 C5.3828125,0 0,5.3833008 0,12 C0,15.3751831 1.4219971,18.5541382 3.9014893,20.8311768 C3.3549194,21.1240234 3,21.6759644 3,22.3076172 C3,23.2407227 3.7587891,24 4.6923828,24 L9.3076172,24 C9.5665283,24 9.8092041,23.9368896 10.0287476,23.8326416 C10.6749878,23.9396973 11.3366699,24 12,24 C12.6602783,24 13.3217773,23.9396973 13.9715576,23.8327637 C14.19104,23.9369507 14.4335938,24 14.6923828,24 L19.3076172,24 C20.2412109,24 21,23.2407227 21,22.3076172 C21,21.6768799 20.645874,21.1257324 20.0985718,20.8317871 Z" fill="#303C42"></path>
							<path d="M1,12 C1,5.9345703 5.9345703,1 12,1 C18.0654297,1 23,5.9345703 23,12 C23,15.1855469 21.6235352,18.1846924 19.2351685,20.2728271 C18.7820435,19.850708 18.5,19.2655029 18.5,18.6176758 L18.5,9.7808228 C19.5421143,9.4423829 19.8998413,8.8184815 19.9472656,8.7236329 C20.0683594,8.4814454 19.9707031,8.1933595 19.7324218,8.0654298 C19.493164,7.9384767 19.1943359,8.0302735 19.0585937,8.2646486 C19.0419922,8.2949219 18.6201172,9 17,9 C15.4023437,9 14.9697266,8.3134766 14.9423828,8.2661133 C14.8154297,8.0258789 14.5214844,7.9311524 14.2763672,8.0527344 C14.0292969,8.1762696 13.9296875,8.4765625 14.0527344,8.7236328 C14.1001587,8.8184814 14.4578857,9.4423828 15.5,9.7808228 L15.5,16 L8.5,16 L8.5,9.7808228 C9.5421143,9.4423829 9.8998413,8.8184815 9.9472656,8.7236329 C10.0683594,8.4814454 9.9707031,8.1933595 9.7324218,8.0654298 C9.4941406,7.9384766 9.1933594,8.0302734 9.0585938,8.2646484 C9.0419922,8.2949219 8.6201172,9 7,9 C5.4023438,9 4.9697266,8.3134766 4.9423828,8.2661133 C4.8154297,8.0258789 4.5214844,7.9311523 4.2763672,8.0527344 C4.0292969,8.1762695 3.9296875,8.4765625 4.0527344,8.7236328 C4.1001587,8.8184814 4.4578857,9.4423828 5.5,9.7808228 L5.5,18.6176758 C5.5,19.2650147 5.2182007,19.8497925 4.7647705,20.2721558 C2.3738403,18.1792603 1,15.1824951 1,12 Z" fill="#FED600"></path>
							<path d="M9.3076172,23 L4.6923828,23 C4.3105469,23 4,22.6894531 4,22.3076172 C4,22.0229492 4.1708984,21.7700195 4.4384766,21.6635742 C5.6914063,21.1621094 6.5,19.9663086 6.5,18.6176758 L6.5,9.9677734 C6.6618652,9.9817505 6.8174438,10 7,10 C7.1825562,10 7.3381348,9.9817505 7.5,9.9677734 L7.5,18.6176757 C7.5,19.9663085 8.3085938,21.1621093 9.5644531,21.6645507 C9.8291016,21.7700195 10,22.0229492 10,22.3076172 C10,22.6894531 9.6894531,23 9.3076172,23 Z" fill="#38A4DD"></path>
							<path d="M9.5644531,21.6645508 C9.5230713,21.6480103 9.4863891,21.6246338 9.4459839,21.6065674 C9.3413086,21.8562622 9.0949097,22.0322266 8.8076172,22.0322266 L4.1923828,22.0322266 C4.151001,22.0322266 4.1150513,22.015564 4.0756836,22.008606 C4.0310059,22.1008301 4,22.2001953 4,22.3076172 C4,22.6894531 4.3105469,23 4.6923828,23 L9.3076172,23 C9.6894531,23 10,22.6894531 10,22.3076172 C10,22.0229492 9.8291016,21.7700195 9.5644531,21.6645508 Z" fill="#010101" opacity="0.1"></path>
							<path d="M10.8757324,22.9371948 C10.9542847,22.7421875 11,22.5303955 11,22.3076172 C11,21.6113281 10.5820312,20.9946289 9.9326172,20.7348633 C9.0624886,20.3862305 8.5,19.5551758 8.5,18.6176758 L8.5,17 L15.5,17 L15.5,18.6176758 C15.5,19.5551758 14.9374886,20.3862305 14.0644531,20.7358399 C13.4179688,20.9946289 13,21.6113281 13,22.3076172 C13,22.5303345 13.0457153,22.7420044 13.1242676,22.9369507 C12.3764038,23.0119629 11.619812,23.012085 10.8757324,22.9371948 Z" fill="#FED600"></path>
							<path d="M19.3076172,23 L14.6923828,23 C14.3105469,23 14,22.6894531 14,22.3076172 C14,22.0229492 14.1708984,21.7700195 14.4384766,21.6635742 C15.6914063,21.1621094 16.5,19.9663086 16.5,18.6176758 L16.5,9.9677734 C16.6618652,9.9817505 16.8174438,10 17,10 C17.1825562,10 17.3381348,9.9817505 17.5,9.9677734 L17.5,18.6176757 C17.5,19.9663085 18.3085938,21.1621093 19.5644531,21.6645507 C19.8291016,21.7700195 20,22.0229492 20,22.3076172 C20,22.6894531 19.6894531,23 19.3076172,23 Z" fill="#38A4DD"></path>
							<g transform="translate(3.000000, 3.000000)" fill="#010101" opacity="0.1">
								<path d="M19.8684692,7.3892212 C19.8320312,7.1414185 19.7942504,6.8939819 19.7415771,6.6518555 C19.7050781,6.4847412 19.6582031,6.3216553 19.6141357,6.1574097 C19.5592651,5.9522705 19.5030517,5.7478638 19.4368286,5.5476075 C19.3782348,5.3710328 19.3124885,5.1979371 19.2453003,5.0253907 C19.1762695,4.8476563 19.1040649,4.671692 19.0262451,4.4986573 C18.9453125,4.3190308 18.8601684,4.1418458 18.7700195,3.9675294 C18.6898803,3.812317 18.6047363,3.6603395 18.5175171,3.5095826 C18.4142456,3.3313599 18.3096314,3.1540528 18.1968384,2.9822999 C18.1086426,2.8477784 18.0137329,2.7184449 17.9199219,2.5881959 C17.7936402,2.413025 17.6681519,2.2372438 17.5321045,2.0700074 C17.4420166,1.9591676 17.3440552,1.8554078 17.2497559,1.7482301 C17.0970459,1.5747682 16.9467774,1.3989869 16.7835694,1.2354127 C16.7270508,1.178833 16.6646729,1.12854 16.6069336,1.0731201 C16.4118042,0.8857422 16.2150269,0.7000122 16.0065308,0.5272827 C17.5640259,2.4252319 18.5,4.8530884 18.5,7.5 C18.5,10.4189453 17.3551636,13.0649414 15.5,15.0341187 L15.5,15.6176758 C15.5,16.2651978 15.7817993,16.8501587 16.2346191,17.2722168 C16.2407226,17.2669067 16.2464599,17.2612305 16.2525634,17.2559204 C16.5298461,17.0124512 16.7920531,16.7556152 17.0413207,16.4887085 C17.0724486,16.4553223 17.102661,16.4211426 17.1333617,16.3873901 C17.3563842,16.1425171 17.5666503,15.8881225 17.7656249,15.6259155 C17.8051757,15.5737304 17.8446044,15.5215454 17.8832396,15.4686279 C18.0668334,15.2175903 18.2375487,14.9584961 18.3986815,14.6937256 C18.4380492,14.6289673 18.4786986,14.5650635 18.5167235,14.4993897 C18.6685179,14.2378541 18.8064574,13.9689332 18.935974,13.6959839 C18.9700927,13.6239624 19.00708,13.5535889 19.0396727,13.4806519 C19.1626585,13.2063599 19.2698363,12.925293 19.3698729,12.6414185 C19.3966063,12.5652466 19.4278563,12.491272 19.4530028,12.4143067 C19.5468749,12.1278687 19.6231078,11.8353272 19.6931761,11.5410157 C19.7119139,11.4619141 19.7366942,11.3851929 19.753723,11.30542 C19.8182982,11.0048829 19.863159,10.6991578 19.9024046,10.392212 C19.9121702,10.3152467 19.9292601,10.2406007 19.9373777,10.1631471 C19.9782104,9.7790527 20,9.3910522 20,9 C20,8.5957642 19.9746094,8.1976318 19.9320679,7.8046875 C19.9168091,7.6643066 19.888916,7.5279541 19.8684692,7.3892212 Z"></path>
								<path d="M0.8324585,16.3450317 C0.8883057,16.4071655 0.9446411,16.4686279 1.0018921,16.5294189 C1.2182617,16.7588501 1.4451294,16.9799804 1.6824951,17.1920776 C1.7109985,17.2175293 1.7399292,17.2424926 1.7687378,17.2677002 C1.8499756,17.1915894 1.9191284,17.1052856 1.9887085,17.0193481 C1.4973755,16.7342529 1.0316162,16.4108276 0.5922852,16.055664 C0.6730957,16.1516113 0.74823,16.2515869 0.8324585,16.3450317 Z"></path>
							</g>
							<path d="M13,22.3076172 C13,21.8167725 13.2158813,21.3726807 13.5649414,21.0584107 C12.6749878,21.3164063 11.7390747,21.4625855 10.7716675,21.4862671 C10.9102173,21.7333984 11,22.0095825 11,22.3076172 C11,22.5300293 10.9543457,22.7414551 10.8760376,22.9360962 C10.9283447,22.9414063 10.9823608,22.9405518 11.0349121,22.9451294 C11.7278442,23.0048218 12.4294434,23.0066528 13.1242676,22.9369507 C13.0457153,22.7420044 13,22.5303345 13,22.3076172 Z" fill="#010101" opacity="0.1"></path>
							<path d="M19.5644531,21.6645508 C19.5230713,21.6480103 19.4863891,21.6246338 19.4459839,21.6065674 C19.3413086,21.8562622 19.0949097,22.0322266 18.8076172,22.0322266 L14.1923828,22.0322266 C14.151001,22.0322266 14.1150513,22.015564 14.0756836,22.008606 C14.0310059,22.1008301 14,22.2001953 14,22.3076172 C14,22.6894531 14.3105469,23 14.6923828,23 L19.3076172,23 C19.6894531,23 20,22.6894531 20,22.3076172 C20,22.0229492 19.8291016,21.7700195 19.5644531,21.6645508 Z" fill="#010101" opacity="0.1"></path>
							<path d="M20.0985718,20.8317871 C22.5758057,18.5588989 24,15.3775024 24,12 C24,5.3833008 18.6171875,0 12,0 C5.3828125,0 0,5.3833008 0,12 C0,15.3751831 1.4219971,18.5541382 3.9014893,20.8311768 C3.3549194,21.1240234 3,21.6759644 3,22.3076172 C3,23.2407227 3.7587891,24 4.6923828,24 L9.3076172,24 C9.5665283,24 9.8092041,23.9368896 10.0287476,23.8326416 C10.6749878,23.9396973 11.3366699,24 12,24 C12.6602783,24 13.3217773,23.9396973 13.9715576,23.8327637 C14.19104,23.9369507 14.4335938,24 14.6923828,24 L19.3076172,24 C20.2412109,24 21,23.2407227 21,22.3076172 C21,21.6768799 20.645874,21.1257324 20.0985718,20.8317871 Z" fill="url(#linearGradient-1)"></path>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'kiss' == $emoji ) {
				?>
				<svg width="24px" height="24px" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<defs>
						<linearGradient x1="4.68688917%" y1="28.8701496%" x2="103.662848%" y2="75.0233967%">
							<stop stop-color="#FFFFFF" stop-opacity="0.2" offset="0%"></stop>
							<stop stop-color="#FFFFFF" stop-opacity="0" offset="100%"></stop>
						</linearGradient>
					</defs>
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<path d="M22.7351685,17.3079224 C23.5505371,15.6600952 24,13.8429565 24,12 C24,5.3833008 18.6171875,0 12,0 C5.3828125,0 0,5.3833008 0,12 C0,18.6166992 5.3828125,24 12,24 C14.1306152,24 16.2146606,23.4221802 18.0594482,22.3379517 L19.6542968,23.8613282 C19.7509766,23.9536133 19.8759766,24 20,24 C20.1240234,24 20.2490234,23.9536133 20.3457031,23.8613281 L23.2783203,21.0605468 C23.7431641,20.6108398 24,20.012207 24,19.375 C24,18.4831543 23.4853516,17.7139282 22.7351685,17.3079224 Z" fill="#303C42"></path>
							<path d="M12,23 C5.9345703,23 1,18.0654297 1,12 C1,5.9345703 5.9345703,1 12,1 C18.0654297,1 23,5.9345703 23,12 C23,13.7468262 22.5650024,15.47052 21.7662964,17.0206909 C21.6957397,17.0147095 21.6278076,17 21.5556641,17 C20.9345703,17 20.4042969,17.3461914 20,17.7451172 C19.5957031,17.3461914 19.0654297,17 18.4443359,17 C17.0966797,17 16,18.0654297 16,19.375 C16,20.012207 16.2568359,20.6108398 16.7236328,21.0620117 L17.2904663,21.6034546 C15.6635742,22.5030518 13.8548584,23 12,23 Z" fill="#FED600"></path>
							<path d="M15.3212891,16.5 C15.7373047,16.1333008 16,15.5966797 16,15 C16,13.8969727 15.1025391,13 14,13 C13.7802734,13 13.5624895,13.0395508 13.3164062,13.1259766 C12.9492187,13.2602539 12.6318359,13.4970704 12.4052734,13.8027344 C12.3085938,13.8935547 11.8623047,13.9892578 11.4863281,14 C11.2109375,14.0083008 10.993164,14.237793 11.0009765,14.5136719 C11.0078125,14.7851563 11.2294922,15 11.5,15 C11.5039063,15 11.5087891,15 11.5126953,15 C11.8955078,14.9897461 12.8261719,14.9121094 13.2001953,14.4082031 C13.3173828,14.2509765 13.4755859,14.1323242 13.6669922,14.0629883 C14.4208984,13.7949219 15,14.3442383 15,15 C15,15.5512695 14.5517578,16 14,16 C13.7236328,16 13.5,16.2236328 13.5,16.5 C13.5,16.7763672 13.7236328,17 14,17 C14.5517578,17 15,17.4487305 15,18 C15,18.5512695 14.5517578,19 14,19 C13.8955078,19 13.7871094,18.9794922 13.6601562,18.9345703 C13.4755859,18.8676758 13.3173828,18.7490234 13.2001953,18.5922851 C12.8261719,18.0878906 11.8955078,18.0102538 11.5126953,18 C11.2792969,17.9931641 11.0068359,18.2119141 11,18.4868164 C10.9931641,18.7631836 11.2109375,18.9926758 11.4873047,19 C11.8544922,19.0092773 12.3085938,19.1074219 12.397461,19.1884766 C12.631836,19.5029297 12.9492188,19.7397461 13.3330079,19.8793946 C13.5624895,19.9604492 13.7802734,20 14,20 C15.1025391,20 16,19.1030273 16,18 C16,17.4033203 15.7373047,16.8666992 15.3212891,16.5 Z" fill="#303C42"></path>
							<path d="M8,7 C6.3457031,7 5,8.3457031 5,10 C5,10.2763672 5.2236328,10.5 5.5,10.5 C5.7763672,10.5 6,10.2763672 6,10 C6,8.8969727 6.8974609,8 8,8 C9.1025391,8 10,8.8969727 10,10 C10,10.2763672 10.2236328,10.5 10.5,10.5 C10.7763672,10.5 11,10.2763672 11,10 C11,8.3457031 9.6542969,7 8,7 Z" fill="#303C42"></path>
							<path d="M13.5,10.5 C13.7763672,10.5 14,10.2763672 14,10 C14,8.8969727 14.8974609,8 16,8 C17.1025391,8 18,8.8969727 18,10 C18,10.2763672 18.2236328,10.5 18.5,10.5 C18.7763672,10.5 19,10.2763672 19,10 C19,8.3457031 17.6542969,7 16,7 C14.3457031,7 13,8.3457031 13,10 C13,10.2763672 13.2236328,10.5 13.5,10.5 Z" fill="#303C42"></path>
							<path d="M22.5849609,20.3393555 L20,22.8085938 L17.4169922,20.3408204 C17.1484375,20.081543 17,19.7387695 17,19.375 C17,18.6166992 17.6474609,18 18.4443359,18 C18.7861328,18 19.2089843,18.293457 19.6044922,18.8056641 C19.7939453,19.0507813 20.2060547,19.0507813 20.3955078,18.8056641 C20.7910156,18.293457 21.2138672,18 21.5556641,18 C22.3525391,18 23,18.6166992 23,19.375 C23,19.7387695 22.8515625,20.081543 22.5849609,20.3393555 Z" fill="#EF4438"></path>
							<path d="M22.0784912,18.0966187 C22.3387451,18.3453979 22.5,18.6882324 22.5,19.0664063 C22.5,19.4301758 22.3515625,19.7729493 22.0849609,20.0307618 L19.5885009,22.4154664 L20,22.8085938 L22.5849609,20.3393555 C22.8515625,20.081543 23,19.7387695 23,19.375 C23,18.7926025 22.6166992,18.2967529 22.0784912,18.0966187 Z" fill="#010101" opacity="0.1"></path>
							<g transform="translate(3.000000, 3.000000)" fill="#010101" opacity="0.1">
								<path d="M19.8736572,7.4229736 C19.8370361,7.1696167 19.7996216,6.9163818 19.7459717,6.6689453 C19.7128296,6.5159912 19.6688843,6.3673096 19.6294556,6.2167969 C19.5718384,5.9969483 19.5133057,5.7775879 19.442627,5.5634156 C19.3917237,5.4092408 19.3330079,5.2589112 19.2755738,5.1078492 C19.1980592,4.9040528 19.117859,4.7015992 19.0287476,4.5037843 C18.9624024,4.3563844 18.8911133,4.2119142 18.8185425,4.0680543 C18.720459,3.8736573 18.6176148,3.6823121 18.5084839,3.4947511 C18.4298096,3.3593141 18.348877,3.225525 18.2646485,3.0938722 C18.1437989,2.9051515 18.0161744,2.7213746 17.8843384,2.5407106 C17.7973023,2.4213869 17.7106934,2.301819 17.6190796,2.1862184 C17.4710693,1.9995729 17.3144531,1.8204957 17.1549072,1.643921 C17.0662231,1.5457765 16.9801025,1.4452516 16.8880005,1.3502809 C16.7023926,1.1591188 16.5065918,0.9784547 16.3076172,0.8010255 C16.2518311,0.7512208 16.1986084,0.6989137 16.1417847,0.6502687 C17.7650757,2.5669557 18.7497559,5.0413209 18.7497559,7.749756 C18.7497559,10.2361452 17.9150391,12.5220338 16.5239258,14.364319 C16.6954346,14.4786987 16.8580322,14.6050415 17,14.7451172 C17.4042969,14.3461914 17.9345703,14 18.5556641,14 C18.6278077,14 18.6957398,14.0147095 18.7662964,14.0206909 C19.1638184,13.2492065 19.4705811,12.4345093 19.6791382,11.595581 C19.6807861,11.5888671 19.6826782,11.5822753 19.6842652,11.5755615 C19.7784424,11.1935425 19.8465577,10.8054199 19.8989258,10.415039 C19.9055176,10.3642577 19.9161377,10.3148193 19.9219971,10.2637939 C19.9721069,9.8452148 20,9.4234619 20,9 C20,8.5995483 19.9755859,8.2049561 19.9337769,7.8156738 C19.9194946,7.6829224 19.8926392,7.5542603 19.8736572,7.4229736 Z"></path>
								<path d="M10.468689,19.8907471 C11.8044434,19.701416 13.0969239,19.2634278 14.2904663,18.6034546 L13.7236328,18.0620117 C13.4936523,17.8397217 13.315918,17.5811767 13.1934814,17.300354 C11.5872192,18.2180176 9.7321777,18.7497559 7.7497558,18.7497559 C5.0413207,18.7497559 2.5668945,17.7650147 0.6502075,16.1417237 C0.6989136,16.1985474 0.7512817,16.2518311 0.8010864,16.3076783 C0.9784546,16.5065919 1.1591797,16.7024537 1.3502807,16.8880006 C1.4451904,16.9800416 1.5455932,17.0661012 1.6437377,17.1547242 C1.8203734,17.3143922 1.9995727,17.4710694 2.1863402,17.6191407 C2.3018798,17.7106324 2.4212645,17.7972413 2.5404051,17.8840943 C2.7212523,18.0160523 2.9052122,18.1437989 3.094116,18.2648316 C3.2255247,18.348938 3.3591917,18.4295655 3.4943235,18.5081788 C3.6821287,18.6174928 3.8738401,18.7205201 4.0685423,18.8187867 C4.212097,18.8911744 4.356262,18.9623414 4.5032957,19.0285035 C4.7015989,19.117859 4.9044187,19.1982423 5.1087034,19.275879 C5.2592771,19.33313 5.4091795,19.3917237 5.562866,19.4424439 C5.7777708,19.5133668 5.9978636,19.5720826 6.2183836,19.6298218 C6.3682249,19.6690674 6.5162352,19.7128296 6.6684568,19.7458496 C6.9161985,19.7995605 7.1696165,19.8370972 7.4233396,19.8737183 C7.5545042,19.8927002 7.6831663,19.9195557 7.8157346,19.9337769 C8.2049561,19.9755859 8.5995483,20 9,20 C9.4476318,20 9.8922119,19.9680786 10.3325806,19.911499 C10.378418,19.9059448 10.4230347,19.8968506 10.468689,19.8907471 Z"></path>
							</g>
							<path d="M22.7351685,17.3079224 C23.5505371,15.6600952 24,13.8429565 24,12 C24,5.3833008 18.6171875,0 12,0 C5.3828125,0 0,5.3833008 0,12 C0,18.6166992 5.3828125,24 12,24 C14.1306152,24 16.2146606,23.4221802 18.0594482,22.3379517 L19.6542968,23.8613282 C19.7509766,23.9536133 19.8759766,24 20,24 C20.1240234,24 20.2490234,23.9536133 20.3457031,23.8613281 L23.2783203,21.0605468 C23.7431641,20.6108398 24,20.012207 24,19.375 C24,18.4831543 23.4853516,17.7139282 22.7351685,17.3079224 Z" fill="url(#linearGradient-1)"></path>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'sad' == $emoji ) {
				?>
				<svg width="24px" height="24px" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<defs>
						<linearGradient x1="4.68716042%" y1="28.8702767%" x2="95.3128417%" y2="71.1297275%">
							<stop stop-color="#FFFFFF" stop-opacity="0.2" offset="0%"></stop>
							<stop stop-color="#FFFFFF" stop-opacity="0" offset="100%"></stop>
						</linearGradient>
					</defs>
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<path d="M12,0 C5.3833008,0 0,5.3833008 0,12 C0,18.6166992 5.3833008,24 12,24 C18.6166992,24 24,18.6166992 24,12 C24,5.3833008 18.6166992,0 12,0 Z" fill="#303C42"></path>
							<path d="M12,23 C5.9345703,23 1,18.0654297 1,12 C1,5.9345703 5.9345703,1 12,1 C18.0654297,1 23,5.9345703 23,12 C23,18.0654297 18.0654297,23 12,23 Z" fill="#FED600"></path>
							<path d="M19.093689,3.6065063 C20.7164307,5.5235595 21.7001953,7.9977417 21.7001953,10.7001953 C21.7001953,16.765625 16.765625,21.7001953 10.7001953,21.7001953 C7.9977417,21.7001953 5.5235596,20.7164307 3.6065063,19.093689 C5.6258545,21.479248 8.6370239,23 12,23 C18.0654297,23 23,18.0654297 23,12 C23,8.6370239 21.479248,5.6258545 19.093689,3.6065063 Z" fill="#010101" opacity="0.1"></path>
							<circle fill="#303C42" cx="8" cy="9" r="1"></circle>
							<circle fill="#303C42" cx="16" cy="9" r="1"></circle>
							<path d="M12,15 L11.9985352,15 C7.7978516,15 6.1674805,17.1103516 6.1000977,17.2001953 C5.9350586,17.4199219 5.9794922,17.7299805 6.1982422,17.8964844 C6.4169922,18.0625 6.7304688,18.0200196 6.8979492,17.8027344 C6.9545898,17.7290039 8.3325195,16 11.9985352,16 L12,16 C15.6669922,16.0004883 17.0454102,17.7294922 17.1000977,17.800293 C17.1982422,17.9311523 17.3481445,18 17.5004883,18 C17.6049805,18 17.709961,17.9672852 17.800293,17.8999023 C18.0209961,17.734375 18.065918,17.4208984 17.8999024,17.199707 C17.8325195,17.1103516 16.2016602,15.0004883 12,15 Z" fill="#303C42"></path>
							<path d="M12,0 C5.3833008,0 0,5.3833008 0,12 C0,18.6166992 5.3833008,24 12,24 C18.6166992,24 24,18.6166992 24,12 C24,5.3833008 18.6166992,0 12,0 Z" fill="url(#linearGradient-1)"></path>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'money' == $emoji ) {
				?>
				<svg width="24px" height="24px" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<defs>
						<linearGradient x1="4.68716042%" y1="28.8702767%" x2="95.3128417%" y2="71.1297275%">
							<stop stop-color="#FFFFFF" stop-opacity="0.2" offset="0%"></stop>
							<stop stop-color="#FFFFFF" stop-opacity="0" offset="100%"></stop>
						</linearGradient>
					</defs>
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<path d="M12,0 C5.3833008,0 0,5.3833008 0,12 C0,18.6166992 5.3833008,24 12,24 C18.6166992,24 24,18.6166992 24,12 C24,5.3833008 18.6166992,0 12,0 Z" fill="#303C42"></path>
							<path d="M12,23 C5.9345703,23 1,18.0654297 1,12 C1,5.9345703 5.9345703,1 12,1 C18.0654297,1 23,5.9345703 23,12 C23,18.0654297 18.0654297,23 12,23 Z" fill="#FED600"></path>
							<path d="M19.119751,3.630249 C20.7561646,5.5509644 21.75,8.0349121 21.75,10.75 C21.75,16.8154297 16.8154297,21.75 10.75,21.75 C8.0349121,21.75 5.5509644,20.7561646 3.630249,19.119751 C5.6494751,21.4898682 8.6496582,23 12,23 C18.0654297,23 23,18.0654297 23,12 C23,8.6496582 21.4898682,5.6494751 19.119751,3.630249 Z" fill="#010101" opacity="0.1"></path>
							<path d="M7.25,11 L5.5,11 C5.2236328,11 5,11.2236328 5,11.5 C5,11.7763672 5.2236328,12 5.5,12 L6.5,12 L6.5,12.5 C6.5,12.7763672 6.7236328,13 7,13 C7.2763672,13 7.5,12.7763672 7.5,12.5 L7.5,11.9747314 C8.3458862,11.8521729 9,11.1292725 9,10.25 C9,9.2851563 8.2148438,8.5 7.25,8.5 L6.75,8.5 C6.3364258,8.5 6,8.1635742 6,7.75 C6,7.3364258 6.3364258,7 6.75,7 L8.5,7 C8.7763672,7 9,6.7763672 9,6.5 C9,6.2236328 8.7763672,6 8.5,6 L7.5,6 L7.5,5.5 C7.5,5.2236328 7.2763672,5 7,5 C6.7236328,5 6.5,5.2236328 6.5,5.5 L6.5,6.0252686 C5.6541138,6.1478271 5,6.8707275 5,7.75 C5,8.7148438 5.7851563,9.5 6.75,9.5 L7.25,9.5 C7.6635742,9.5 8,9.8364258 8,10.25 C8,10.6635742 7.6635742,11 7.25,11 Z" fill="#303C42"></path>
							<path d="M16.75,7 L18.5,7 C18.7763672,7 19,6.7763672 19,6.5 C19,6.2236328 18.7763672,6 18.5,6 L17.5,6 L17.5,5.5 C17.5,5.2236328 17.2763672,5 17,5 C16.7236328,5 16.5,5.2236328 16.5,5.5 L16.5,6.0252686 C15.6541138,6.1478271 15,6.8707275 15,7.75 C15,8.7148438 15.7851563,9.5 16.75,9.5 L17.25,9.5 C17.6635742,9.5 18,9.8364258 18,10.25 C18,10.6635742 17.6635742,11 17.25,11 L15.5,11 C15.2236328,11 15,11.2236328 15,11.5 C15,11.7763672 15.2236328,12 15.5,12 L16.5,12 L16.5,12.5 C16.5,12.7763672 16.7236328,13 17,13 C17.2763672,13 17.5,12.7763672 17.5,12.5 L17.5,11.9747314 C18.3458862,11.8521729 19,11.1292725 19,10.25 C19,9.2851562 18.2148437,8.5 17.25,8.5 L16.75,8.5 C16.3364258,8.5 16,8.1635742 16,7.75 C16,7.3364258 16.3364258,7 16.75,7 Z" fill="#303C42"></path>
							<path d="M18.5004883,14.0073242 L5.5004883,14 L5.5,14 C5.347168,14 5.2026367,14.0698242 5.1079102,14.1894531 C5.0131836,14.3095703 4.9780274,14.4663086 5.0131836,14.6147461 C5.3817139,16.173645 6.5036621,17.7096558 8.0269775,18.7748413 C8.1655884,20.7110596 9.7167969,22 12,22 C14.282959,22 15.8341064,20.7112427 15.9729614,18.7753296 C17.4940185,17.7163696 18.6159668,16.1829224 18.9863281,14.6230469 C19.0219726,14.4741211 18.9873047,14.3173828 18.8925781,14.1972656 C18.7978516,14.0776367 18.6533203,14.0073242 18.5004883,14.0073242 Z" fill="#303C42"></path>
							<path d="M12,21 C10.6689453,21 9.1225586,20.394043 9.0068359,18.7055664 C9.894226,17.8817749 10.7105713,17.8485107 11.5,18.2211914 L11.5,19 C11.5,19.2763672 11.7236328,19.5 12,19.5 C12.2763672,19.5 12.5,19.2763672 12.5,19 L12.5,18.2421265 C12.8239136,18.0951538 13.1569214,18 13.5,18 C14.0141602,18 14.46875,18.2124023 14.9931641,18.7041016 C14.878418,20.3935547 13.331543,21 12,21 Z" fill="#E53A35"></path>
							<path d="M14.9125977,19.1439819 C14.9474488,19.0036621 14.9823609,18.8632202 14.9931641,18.7041015 C14.46875,18.2124023 14.0141602,18 13.5,18 C13.1569214,18 12.8239136,18.0951538 12.5,18.2421265 L12.5,18.7489014 C12.8239136,18.6019287 13.1569214,18.5067749 13.5,18.5067749 C13.9870605,18.5067749 14.4224854,18.7059326 14.9125977,19.1439819 Z" fill="#FFFFFF" opacity="0.2"></path>
							<path d="M11.5,18.7279663 L11.5,18.2211914 C10.7105713,17.8485107 9.8942261,17.8817749 9.0068359,18.7055664 C9.0177612,18.8646851 9.0527343,19.0051269 9.0877075,19.1454468 C9.9436646,18.3936157 10.7348022,18.3666992 11.5,18.7279663 Z" fill="#FFFFFF" opacity="0.2"></path>
							<path d="M15.5344849,17.8468628 C15.0352783,17.4071655 14.3803711,17 13.5,17 C12.9819336,17 12.4785156,17.1176758 12,17.3500977 C11.5214844,17.1176758 11.0180664,17 10.5,17 C9.6278076,17 8.9709473,17.4078369 8.4678345,17.8475342 C7.414856,17.0748291 6.5910645,16.0646363 6.178711,15.0004883 L17.8208008,15.006836 C17.4078369,16.0712891 16.5847168,17.0786743 15.5344849,17.8468628 Z" fill="#B72025"></path>
							<path d="M7.9954143,17.290493 C7.4505172,16.6451206 7.9286566,15.6534614 8.7732974,15.653923 L17.5020143,15.6586914 C17.6215211,15.4442139 17.7350465,15.2278442 17.8208009,15.0068359 L6.1787109,15.0004883 C6.5910644,16.0646362 7.4148559,17.0748291 8.4678344,17.8475342 C8.4765624,17.8399048 8.4871825,17.8331299 8.4959716,17.8255615 C8.3184614,17.6536808 8.1511192,17.4749107 7.9954143,17.290493 Z" fill="#010101" opacity="0.1"></path>
							<path d="M12,0 C5.3833008,0 0,5.3833008 0,12 C0,18.6166992 5.3833008,24 12,24 C18.6166992,24 24,18.6166992 24,12 C24,5.3833008 18.6166992,0 12,0 Z" fill="url(#linearGradient-1)"></path>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'unimpressed' == $emoji ) {
				?>
				<svg width="24px" height="24px" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<path d="M12,0 C5.3833008,0 0,5.3833008 0,12 C0,18.6166992 5.3833008,24 12,24 C18.6166992,24 24,18.6166992 24,12 C24,5.3833008 18.6166992,0 12,0 Z" fill="#303C42"></path>
							<path d="M12,23 C5.9345703,23 1,18.0654297 1,12 C1,5.9345703 5.9345703,1 12,1 C18.0654297,1 23,5.9345703 23,12 C23,18.0654297 18.0654297,23 12,23 Z" fill="#FED600"></path>
							<path d="M19.119751,3.630249 C20.7561646,5.5509644 21.75,8.0349121 21.75,10.75 C21.75,16.8154297 16.8154297,21.75 10.75,21.75 C8.0349121,21.75 5.5509644,20.7561646 3.630249,19.119751 C5.6494751,21.4898682 8.6496582,23 12,23 C18.0654297,23 23,18.0654297 23,12 C23,8.6496582 21.4898682,5.6494751 19.119751,3.630249 Z" fill="#010101" opacity="0.1"></path>
							<path d="M17.5,9 L14.5,9 C14.2236328,9 14,9.2236328 14,9.5 C14,9.7763672 14.2236328,10 14.5,10 L15,10 C15,10.5512695 15.4487305,11 16,11 C16.5512695,11 17,10.5512695 17,10 L17.5,10 C17.7763672,10 18,9.7763672 18,9.5 C18,9.2236328 17.7763672,9 17.5,9 Z" fill="#303C42"></path>
							<path d="M9,10 L9.5,10 C9.7763672,10 10,9.7763672 10,9.5 C10,9.2236328 9.7763672,9 9.5,9 L6.5,9 C6.2236328,9 6,9.2236328 6,9.5 C6,9.7763672 6.2236328,10 6.5,10 L7,10 C7,10.5512695 7.4487305,11 8,11 C8.5512695,11 9,10.5512695 9,10 Z" fill="#303C42"></path>
							<path d="M15.5,17 L8.5,17 C8.2236328,17 8,17.2236328 8,17.5 C8,17.7763672 8.2236328,18 8.5,18 L15.5,18 C15.7763672,18 16,17.7763672 16,17.5 C16,17.2236328 15.7763672,17 15.5,17 Z" fill="#303C42"></path>
							<path d="M12,0 C5.3833008,0 0,5.3833008 0,12 C0,18.6166992 5.3833008,24 12,24 C18.6166992,24 24,18.6166992 24,12 C24,5.3833008 18.6166992,0 12,0 Z" fill="url(#linearGradient-1)"></path>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'gross' == $emoji ) {
				?>
				<svg width="24px" height="24px" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<path d="M12,0 C5.3833008,0 0,5.3833008 0,12 C0,18.6166992 5.3833008,24 12,24 C18.6166992,24 24,18.6166992 24,12 C24,5.3833008 18.6166992,0 12,0 Z" fill="#303C42"></path>
							<path d="M12,23 C5.9345703,23 1,18.0654297 1,12 C1,5.9345703 5.9345703,1 12,1 C18.0654297,1 23,5.9345703 23,12 C23,18.0654297 18.0654297,23 12,23 Z" fill="#C0CA33"></path>
							<path d="M19.119751,3.630249 C20.7561646,5.5509644 21.75,8.0349121 21.75,10.75 C21.75,16.8154297 16.8154297,21.75 10.75,21.75 C8.0349121,21.75 5.5509644,20.7561646 3.630249,19.119751 C5.6494751,21.4898682 8.6496582,23 12,23 C18.0654297,23 23,18.0654297 23,12 C23,8.6496582 21.4898682,5.6494751 19.119751,3.630249 Z" fill="#010101" opacity="0.1"></path>
							<circle fill="#303C42" cx="16" cy="9" r="1"></circle>
							<circle fill="#303C42" cx="8" cy="9" r="1"></circle>
							<path d="M17.5,13 C17.7763672,13 18,12.7763672 18,12.5 C18,12.2236328 17.7763672,12 17.5,12 C15.7415161,12 14.2957764,13.3083496 14.0505371,15 L9.9494629,15 C9.7042236,13.3083496 8.2584839,12 6.5,12 C6.2236328,12 6,12.2236328 6,12.5 C6,12.7763672 6.2236328,13 6.5,13 C7.878418,13 9,14.121582 9,15.5 C9,16.878418 7.878418,18 6.5,18 C6.2236328,18 6,18.2236328 6,18.5 C6,18.7763672 6.2236328,19 6.5,19 C8.2584839,19 9.7042236,17.6916504 9.9494629,16 L14.0505371,16 C14.2957764,17.6916504 15.7415161,19 17.5,19 C17.7763672,19 18,18.7763672 18,18.5 C18,18.2236328 17.7763672,18 17.5,18 C16.121582,18 15,16.878418 15,15.5 C15,14.121582 16.121582,13 17.5,13 Z" fill="#303C42"></path>
							<path d="M12,0 C5.3833008,0 0,5.3833008 0,12 C0,18.6166992 5.3833008,24 12,24 C18.6166992,24 24,18.6166992 24,12 C24,5.3833008 18.6166992,0 12,0 Z" fill="url(#linearGradient-1)"></path>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'love' == $emoji ) {
				?>
				<svg width="24px" height="24px" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<path d="M12,0 C5.3828125,0 0,5.3833008 0,12 C0,18.6166992 5.3828125,24 12,24 C18.6171875,24 24,18.6166992 24,12 C24,5.3833008 18.6171875,0 12,0 Z" fill="#303C42"></path>
							<path d="M12,23 C5.9345703,23 1,18.0654297 1,12 C1,5.9345703 5.9345703,1 12,1 C18.0654297,1 23,5.9345703 23,12 C23,18.0654297 18.0654297,23 12,23 Z" fill="#FED600"></path>
							<path d="M19.119751,3.630249 C20.7561646,5.5509644 21.75,8.0349121 21.75,10.75 C21.75,16.8154297 16.8154297,21.75 10.75,21.75 C8.0349121,21.75 5.5509644,20.7561646 3.630249,19.119751 C5.6494751,21.4898682 8.6496582,23 12,23 C18.0654297,23 23,18.0654297 23,12 C23,8.6496582 21.4898682,5.6494751 19.119751,3.630249 Z" fill="#010101" opacity="0.1"></path>
							<path d="M18.4394531,14.0209961 C18.1748047,13.9550781 17.9013672,14.1230469 17.8378906,14.3916016 C17.1933594,17.1049805 14.7929688,19 12,19 C9.203125,19 6.8017578,17.1020508 6.1601562,14.3852539 C6.0976562,14.1162109 5.8310546,13.953125 5.5585937,14.0131836 C5.290039,14.0766602 5.1240234,14.3461914 5.1874923,14.6147461 C5.9355469,17.7856445 8.7373047,20 12,20 C15.2587891,20 18.0585938,17.7890625 18.8105469,14.6230469 C18.8740234,14.3540039 18.7080078,14.0844727 18.4394531,14.0209961 Z" fill="#303C42"></path>
							<path d="M7,13 C7.1240234,13 7.2490234,12.9536133 7.3457031,12.8613281 L10.2783203,10.0605468 C10.7431641,9.6108398 11,9.012207 11,8.375 C11,7.0654297 9.9033203,6 8.5556641,6 C7.9345703,6 7.4042969,6.3461914 7,6.7451172 C6.5957031,6.3461914 6.0654297,6 5.4443359,6 C4.0966797,6 3,7.0654297 3,8.375 C3,9.012207 3.2568359,9.6108398 3.7236328,10.0620117 L6.6542969,12.8613281 C6.7509766,12.9536133 6.8759766,13 7,13 Z" fill="#303C42"></path>
							<path d="M4,8.375 C4,7.6166992 4.6474609,7 5.4443359,7 C5.7861328,7 6.2089843,7.293457 6.6044922,7.8056641 C6.7939453,8.0507813 7.2060547,8.0507813 7.3955078,7.8056641 C7.7910156,7.293457 8.2138672,7 8.5556641,7 C9.3525391,7 10,7.6166992 10,8.375 C10,8.7387695 9.8515625,9.081543 9.5849609,9.3393555 L7,11.8085938 L4.4169922,9.3408203 C4.1484375,9.081543 4,8.7387695 4,8.375 Z" fill="#EF4438"></path>
							<path d="M9.3712769,7.2416992 C9.5114136,7.4535522 9.5957032,7.7022705 9.5957032,7.9707031 C9.5957032,8.3344726 9.4472657,8.6772461 9.1806641,8.9350586 L6.5957032,11.4042969 L7,11.8085938 L9.5849609,9.3393555 C9.8515625,9.081543 10,8.7387695 10,8.375 C10,7.9047852 9.7504272,7.4897461 9.3712769,7.2416992 Z" fill="#010101" opacity="0.1"></path>
							<path d="M18.5556641,6 C17.9345703,6 17.4042969,6.3461914 17,6.7451172 C16.5957031,6.3461914 16.0654297,6 15.4443359,6 C14.0966797,6 13,7.0654297 13,8.375 C13,9.012207 13.2568359,9.6108398 13.7236328,10.0620117 L16.6542969,12.8613281 C16.7509766,12.9536133 16.8759766,13 17,13 C17.1240234,13 17.2490234,12.9536133 17.3457031,12.8613281 L20.2783203,10.0605468 C20.7431641,9.6108398 21,9.012207 21,8.375 C21,7.0654297 19.9033203,6 18.5556641,6 Z" fill="#303C42"></path>
							<path d="M19.5849609,9.3393555 L17,11.8085938 L14.4169922,9.3408204 C14.1484375,9.081543 14,8.7387695 14,8.375 C14,7.6166992 14.6474609,7 15.4443359,7 C15.7861328,7 16.2089843,7.293457 16.6044922,7.8056641 C16.7939453,8.0507813 17.2060547,8.0507813 17.3955078,7.8056641 C17.7910156,7.293457 18.2138672,7 18.5556641,7 C19.3525391,7 20,7.6166992 20,8.375 C20,8.7387695 19.8515625,9.081543 19.5849609,9.3393555 Z" fill="#EF4438"></path>
							<path d="M19.3712769,7.2416992 C19.5114136,7.4535522 19.5957032,7.7022705 19.5957032,7.9707031 C19.5957032,8.3344726 19.4472657,8.6772461 19.1806641,8.9350586 L16.5957032,11.4042969 L17,11.8085938 L19.5849609,9.3393555 C19.8515625,9.081543 20,8.7387695 20,8.375 C20,7.9047852 19.7504272,7.4897461 19.3712769,7.2416992 Z" fill="#010101" opacity="0.1"></path>
							<path d="M12,0 C5.3828125,0 0,5.3833008 0,12 C0,18.6166992 5.3828125,24 12,24 C18.6171875,24 24,18.6166992 24,12 C24,5.3833008 18.6171875,0 12,0 Z" fill="url(#linearGradient-1)"></path>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'yikes' == $emoji ) {
				?>
				<svg width="24px" height="24px" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<path d="M24,6 C24,4.4873047 21.6572266,1.5205078 21.390625,1.1875 C21.1992187,0.9501953 20.8007812,0.9501953 20.609375,1.1875 C20.4985352,1.3259888 20.0278931,1.9224243 19.5167847,2.6777954 C17.3827515,0.9536743 14.7404785,0 12,0 C5.3828125,0 0,5.3833008 0,12 C0,18.6166992 5.3828125,24 12,24 C18.6171875,24 24,18.6166992 24,12 C24,10.6173096 23.7481689,9.2536011 23.2721558,7.9364624 C23.7195435,7.4123535 24,6.7415161 24,6 Z" fill="#303C42"></path>
							<path d="M12,23 C5.9345703,23 1,18.0654297 1,12 C1,5.9345703 5.9345703,1 12,1 C14.5475464,1 17.0029907,1.8990479 18.9742432,3.5235596 C18.447876,4.399231 18,5.338623 18,6 C18,7.6542969 19.3457031,9 21,9 C21.5270386,9 22.0153809,8.8515625 22.446228,8.6119385 C22.8067017,9.7153931 23,10.8509521 23,12 C23,18.0654297 18.0654297,23 12,23 Z" fill="#FED600"></path>
							<path d="M11.9980469,13.9985352 C9.163086,13.9985352 6.6259766,15.6894532 5.5341797,18.3066407 C5.4707031,18.4609376 5.4873047,18.6372071 5.5800781,18.7763673 C5.6728515,18.9155275 5.8291015,18.9990236 5.9960937,18.9990236 L18.0009766,19 C18.1679688,19 18.3242188,18.9165039 18.4169922,18.7773437 C18.5097656,18.6381835 18.5263672,18.461914 18.4628906,18.3076171 C17.3710938,15.6899414 14.8339844,13.9985352 11.9980469,13.9985352 Z" fill="#303C42"></path>
							<path d="M6.7998047,17.9990234 C7.8613281,16.1542968 9.828125,14.9985351 11.9980469,14.9985351 C14.1689453,14.9985351 16.1357422,16.1547851 17.1972657,17.9999999 L6.7998047,17.9990234 Z" fill="#B72025"></path>
							<path d="M12.848877,15.8493652 C14.2646485,15.8493652 15.5882569,16.3478393 16.6359253,17.2017822 C15.5161133,15.8314209 13.833313,14.9985351 11.9980469,14.9985351 C9.828125,14.9985351 7.8613281,16.1542968 6.7998047,17.9990234 L8.2581787,17.9991455 C9.3780518,16.6615601 11.0387573,15.8493652 12.848877,15.8493652 Z" fill="#010101" opacity="0.1"></path>
							<circle fill="#303C42" cx="8" cy="9" r="1"></circle>
							<circle fill="#303C42" cx="16" cy="9" r="1"></circle>
							<path d="M21,2.3173828 C21.8955078,3.5131836 23,5.2382813 23,6 C23,7.1030273 22.1025391,8 21,8 C19.8974609,8 19,7.1030273 19,6 C19,5.2387695 20.1044922,3.5136719 21,2.3173828 Z" fill="#38A4DD"></path>
							<path d="M21,7.1826172 C20.0568237,7.1826172 19.2684937,6.5241699 19.05896,5.6438599 C19.022522,5.7767334 19,5.8980713 19,6 C19,7.1030273 19.8974609,8 21,8 C22.1025391,8 23,7.1030273 23,6 C23,5.8980713 22.9775391,5.7766113 22.9411011,5.6437378 C22.7315674,6.5241089 21.9432373,7.1826172 21,7.1826172 Z" fill="#010101" opacity="0.1"></path>
							<path d="M23,12 C23,11.6490479 22.9741821,11.3045654 22.9419556,10.9621582 C22.9248047,10.791626 22.9038697,10.621521 22.8785401,10.4519043 C22.8611451,10.3291016 22.8381348,10.208252 22.8167115,10.086792 C22.7250367,9.590271 22.6048585,9.0975952 22.4462281,8.6119385 C22.1831666,8.7582398 21.8929444,8.8535156 21.5913087,8.9188233 C21.6917725,9.5147705 21.75,10.1252441 21.75,10.75 C21.75,16.8251343 16.8251343,21.75 10.75,21.75 C8.0415039,21.75 5.5670776,20.7652588 3.6503296,19.1418457 C3.6987915,19.1984253 3.7509766,19.2514648 3.8005371,19.3070679 C3.9782104,19.5063477 4.1592407,19.7025757 4.350708,19.8884278 C4.4452515,19.9801636 4.5452881,20.065857 4.6430664,20.1541749 C4.8200073,20.314148 4.9995727,20.4710694 5.1866455,20.6193849 C5.3020019,20.7107545 5.4212036,20.7971803 5.5402222,20.8839723 C5.7211304,21.0160524 5.9052735,21.143921 6.0943604,21.2649537 C6.225647,21.3489381 6.3591309,21.4296266 6.4941407,21.5081178 C6.68219,21.6175538 6.8740845,21.7207032 7.0690308,21.8190309 C7.2123413,21.8913576 7.3563843,21.9623414 7.5031739,22.0284425 C7.7014161,22.117798 7.9042969,22.1981202 8.1085816,22.275818 C8.2593384,22.33313 8.4094239,22.3917848 8.5632325,22.442566 C8.777588,22.5133057 8.9970094,22.5718385 9.2169801,22.6295167 C9.3674318,22.6689454 9.5160524,22.7128297 9.6689454,22.7459718 C9.916443,22.7996217 10.1696168,22.8370363 10.4229737,22.8736573 C10.5542603,22.8926392 10.6829224,22.9194947 10.8156739,22.9337769 C11.2049561,22.9755859 11.5995483,23 12,23 C18.0654297,23 23,18.0654297 23,12 Z" fill="#010101" opacity="0.1"></path>
							<path d="M21,9 C20.2203979,9 19.5157471,8.6938477 18.9817505,8.2046509 L22.9892578,12.2120972 C22.9906006,12.1408081 23,12.0715942 23,12 C23,10.8509521 22.8067017,9.7153931 22.446228,8.6119385 C22.0153809,8.8515625 21.5270386,9 21,9 Z" fill="url(#linearGradient-1)"></path>
							<path d="M24,6 C24,4.4873047 21.6572266,1.5205078 21.390625,1.1875 C21.1992187,0.9501953 20.8007812,0.9501953 20.609375,1.1875 C20.4985352,1.3259888 20.0278931,1.9224243 19.5167847,2.6777954 C17.3827515,0.9536743 14.7404785,0 12,0 C5.3828125,0 0,5.3833008 0,12 C0,18.6166992 5.3828125,24 12,24 C18.6171875,24 24,18.6166992 24,12 C24,10.6173096 23.7481689,9.2536011 23.2721558,7.9364624 C23.7195435,7.4123535 24,6.7415161 24,6 Z" fill="url(#linearGradient-2)"></path>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'cool' == $emoji ) {
				?>
				<svg width="24px" height="24px" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<path d="M24,6.5 C24,5.121582 22.8789063,4 21.5,4 L20.9307861,4 C18.6530151,1.460022 15.4153442,0 12,0 C8.5872803,0 5.3501587,1.4598389 3.0698853,4 L2.5,4 C1.1210938,4 0,5.121582 0,6.5 L0,7.5 C0,8.1326904 0.112854,8.7382202 0.3103638,9.3044434 C0.1084595,10.1858521 0,11.0913696 0,12 C0,18.6166992 5.3828125,24 12,24 C18.6171875,24 24,18.6166992 24,12 C24,11.0900269 23.8921509,10.1845703 23.6898193,9.3039551 C23.8872681,8.737854 24,8.1325073 24,7.5 L24,6.5 Z" fill="#303C42"></path>
							<path d="M23,12 C23,18.0654297 18.0654297,23 12,23 C5.9345703,23 1,18.0654297 1,12 C1,11.5819092 1.0264893,11.1647339 1.0734253,10.7503662 C2.0756836,12.1114502 3.6842041,13 5.5,13 C8.4819336,13 10.9124146,10.6123657 10.9924316,7.6489868 C11.109375,7.4651489 11.4574585,7 12,7 C12.5441895,7 12.8927612,7.4680786 13.0075684,7.6491089 C13.0876465,10.6125488 15.5181274,13 18.5,13 C20.315979,13 21.9247437,12.1112671 22.9269409,10.7498779 C22.9738159,11.1640625 23,11.5814819 23,12 Z" fill="#FED600"></path>
							<path d="M22.9269409,10.7498779 C22.6499634,11.1260986 22.322876,11.4615478 21.9616699,11.7568359 C21.5699463,17.4690552 16.8099365,22 11,22 C8.2213745,22 5.687561,20.9562378 3.7492676,19.2507324 C5.7666626,21.543457 8.7131958,23 12,23 C18.0654297,23 23,18.0654297 23,12 C23,11.5814819 22.9738159,11.1640625 22.9269409,10.7498779 Z" fill="#010101" opacity="0.1"></path>
							<path d="M18.6181641,14.0214844 C18.3554688,13.9560547 18.0800782,14.1206055 18.0146485,14.3886719 C17.3515625,17.1040039 14.8789063,18.9999979 12.0009766,18.9999979 C9.1201172,18.9999979 6.6464844,17.1010742 5.9863282,14.3818359 C5.9208985,14.1137695 5.6523438,13.9492187 5.381836,14.0141601 C5.1132813,14.0791015 4.9492188,14.3496093 5.0136719,14.618164 C5.7841797,17.7866211 8.6572266,19.9999979 12.0009766,19.9999979 C15.3417969,19.9999979 18.2138672,17.7900391 18.9853516,14.6259766 C19.0507813,14.3574219 18.8867188,14.0869141 18.6181641,14.0214844 Z" fill="#303C42"></path>
							<path d="M23,6.5 L23,7.5 C23,9.9814453 20.9814453,12 18.5,12 C16.0185547,12 14,9.9814453 14,7.5 L14,6.5 C14,5.6728516 14.6728516,5 15.5,5 L21.5,5 C22.3271484,5 23,5.6728516 23,6.5 Z" fill="#5C6771"></path>
							<path d="M23,6.5 L23,7.5 C23,9.9814453 20.9814453,12 18.5,12 C16.0185547,12 14,9.9814453 14,7.5 L14,6.5 C14,5.6728516 14.6728516,5 15.5,5 L21.5,5 C22.3271484,5 23,5.6728516 23,6.5 Z" fill="#5C6771"></path>
							<path d="M13.0205688,6.2961426 C12.7429199,6.1275024 12.4085083,6 12,6 C11.5914917,6 11.2570801,6.1275024 10.9794312,6.2961426 C10.9393921,5.8111572 10.7653809,5.3673706 10.4873657,5 L13.5126343,5 C13.2346191,5.3673706 13.0606079,5.8111572 13.0205688,6.2961426 Z" fill="#FED600"></path>
							<path d="M12,1 C14.8207397,1 17.5123291,2.0828247 19.5450439,4 L4.4554443,4 C6.4901123,2.0824585 9.1813965,1 12,1 Z" fill="#FED600"></path>
							<path d="M1,6.5 C1,5.6728516 1.6728516,5 2.5,5 L8.5,5 C9.3271484,5 10,5.6728516 10,6.5 L10,7.5 C10,9.9814453 7.9814453,12 5.5,12 C3.0185547,12 1,9.9814453 1,7.5 L1,6.5 Z" fill="#5C6771"></path>
							<path d="M9.0936279,5.1236572 C9.1725464,5.3059692 9.2172851,5.5062866 9.2172851,5.7172851 L9.2172851,6.7172851 C9.2172851,9.1987304 7.1987304,11.2172851 4.7172851,11.2172851 C3.6762084,11.2172851 2.7287597,10.8474731 1.9655151,10.25177 C2.7897339,11.3077393 4.0596313,12 5.5,12 C7.9814453,12 10,9.9814453 10,7.5 L10,6.5 C10,5.8838501 9.6260376,5.354248 9.0936279,5.1236572 Z" fill="#010101" opacity="0.1"></path>
							<path d="M22.0936279,5.1236572 C22.1725464,5.3059692 22.2172851,5.5062866 22.2172851,5.7172851 L22.2172851,6.7172851 C22.2172851,9.1987304 20.1987304,11.2172851 17.7172851,11.2172851 C16.6762084,11.2172851 15.7287597,10.8474731 14.9655151,10.25177 C15.7897339,11.3077393 17.0596313,12 18.5,12 C20.9814453,12 23,9.9814453 23,7.5 L23,6.5 C23,5.8838501 22.6260376,5.354248 22.0936279,5.1236572 Z" fill="#010101" opacity="0.1"></path>
							<path d="M1,6.5 C1,5.6728516 1.6728516,5 2.5,5 L8.5,5 C9.3271484,5 10,5.6728516 10,6.5 L10,7.5 C10,9.9814453 7.9814453,12 5.5,12 C3.0185547,12 1,9.9814453 1,7.5 L1,6.5 Z" fill="url(#linearGradient-1)"></path>
							<path d="M23,6.5 L23,7.5 C23,9.9814453 20.9814453,12 18.5,12 C16.0185547,12 14,9.9814453 14,7.5 L14,6.5 C14,5.6728516 14.6728516,5 15.5,5 L21.5,5 C22.3271484,5 23,5.6728516 23,6.5 Z" fill="url(#linearGradient-1)"></path>
							<path d="M24,6.5 C24,5.121582 22.8789063,4 21.5,4 L20.9307861,4 C18.6530151,1.460022 15.4153442,0 12,0 C8.5872803,0 5.3501587,1.4598389 3.0698853,4 L2.5,4 C1.1210938,4 0,5.121582 0,6.5 L0,7.5 C0,8.1326904 0.112854,8.7382202 0.3103638,9.3044434 C0.1084595,10.1858521 0,11.0913696 0,12 C0,18.6166992 5.3828125,24 12,24 C18.6171875,24 24,18.6166992 24,12 C24,11.0900269 23.8921509,10.1845703 23.6898193,9.3039551 C23.8872681,8.737854 24,8.1325073 24,7.5 L24,6.5 Z" fill="url(#linearGradient-2)"></path>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'confused' == $emoji ) {
				?>
				<svg width="24px" height="24px" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<path d="M12,0 C5.3828125,0 0,5.3828125 0,12 C0,18.6171875 5.3828125,24 12,24 C18.6171875,24 24,18.6171875 24,12 C24,5.3828125 18.6171875,0 12,0 Z" fill="#303C42"></path>
							<path d="M12,23 C5.9345703,23 1,18.0654297 1,12 C1,5.9345703 5.9345703,1 12,1 C15.0280762,1 17.7739258,2.2303467 19.7650146,4.2167969 C19.5402222,4.0822144 19.2805176,4 19,4 C18.1728516,4 17.5,4.6728516 17.5,5.5 C17.5,5.7763672 17.7236328,6 18,6 C18.2763672,6 18.5,5.7763672 18.5,5.5 C18.5,5.2246094 18.7246094,5 19,5 C19.2753906,5 19.5,5.2246094 19.5,5.5 L19.5,5.9414063 C19.5,6.0957032 19.4140625,6.2333985 19.2763672,6.3027344 C18.7978516,6.5419922 18.5,7.0234375 18.5,7.5585938 L18.5,8 C18.5,8.2763672 18.7236328,8.5 19,8.5 C19.2763672,8.5 19.5,8.2763672 19.5,8 L19.5,7.5585938 C19.5,7.4042969 19.5859375,7.2666016 19.7236328,7.1972657 C20.2021484,6.9580078 20.5,6.4765625 20.5,5.9414063 L20.5,5.5 C20.5,5.2699585 20.4437256,5.0544434 20.3508301,4.859436 C21.9981079,6.7830811 23,9.2747803 23,12 C23,18.0654297 18.0654297,23 12,23 Z" fill="#FED600"></path>
							<path d="M19.3987427,4.057251 C19.5284424,4.0946656 19.6513062,4.1487427 19.7650147,4.2167969 C19.5045777,3.9569702 19.2298584,3.711792 18.9447022,3.4789429 C19.1015625,3.6672363 19.2544556,3.8587646 19.3987427,4.057251 Z" fill="#010101" opacity="0.1"></path>
							<path d="M20.3508301,4.859436 C20.4437256,5.0544434 20.5,5.2699585 20.5,5.5 L20.5,5.9414063 C20.5,5.9430542 20.4993286,5.9446412 20.4993286,5.9462891 C21.1368408,7.3348999 21.5,8.8741455 21.5,10.5 C21.5,16.5654297 16.5654297,21.5 10.5,21.5 C7.8484497,21.5 5.413147,20.5567017 3.5115967,18.9884033 C5.5307617,21.4366455 8.5861206,23 12,23 C18.0654297,23 23,18.0654297 23,12 C23,9.2747803 21.9981079,6.7830811 20.3508301,4.859436 Z" fill="#010101" opacity="0.1"></path>
							<circle fill="#303C42" cx="8.5" cy="10" r="1"></circle>
							<circle fill="#303C42" cx="15" cy="10" r="1"></circle>
							<path d="M14.5,8 C14.5117188,8 15.7011719,8.0195313 16.0527344,8.7236328 C16.140625,8.8984375 16.3173828,9 16.5,9 C16.5751953,9 16.6513672,8.9833984 16.7236328,8.9472656 C16.9707031,8.8232422 17.0703125,8.5234375 16.9472656,8.2763672 C16.3164063,7.0146484 14.5742188,7 14.5,7 C14.2236328,7 14,7.2236328 14,7.5 C14,7.7763672 14.2236328,8 14.5,8 Z" fill="#303C42"></path>
							<path d="M6.4853516,8.6210938 C6.4892578,8.6054688 6.9140625,7 9,7 C9.2763672,7 9.5,6.7763672 9.5,6.5 C9.5,6.2236328 9.2763672,6 9,6 C6.7138672,6 5.7207031,7.5556641 5.5146484,8.3789063 C5.4482422,8.6464844 5.6103516,8.9179688 5.8789063,8.9853516 C5.9199219,8.9951172 5.9599609,9 6,9 C6.2246094,9 6.4287109,8.8486328 6.4853516,8.6210938 Z" fill="#303C42"></path>
							<path d="M17.5,16 L6.5,16 C6.2236328,16 6,16.2236328 6,16.5 C6,16.7763672 6.2236328,17 6.5,17 L17.5,17 C17.7763672,17 18,16.7763672 18,16.5 C18,16.2236328 17.7763672,16 17.5,16 Z" fill="#303C42"></path>
							<circle fill="#303C42" cx="19" cy="9.5" r="1"></circle>
							<path d="M12,0 C5.3828125,0 0,5.3828125 0,12 C0,18.6171875 5.3828125,24 12,24 C18.6171875,24 24,18.6171875 24,12 C24,5.3828125 18.6171875,0 12,0 Z" fill="url(#linearGradient-1)"></path>
						</g>
					</g>
				</svg>
				<?php
			} elseif ( 'sleepy' == $emoji ) {
				?>
				<svg width="24px" height="24px" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
					<g stroke="none" stroke-width="1" fill="rgba(0,0,0,0)" fill-rule="evenodd">
						<g fill-rule="nonzero">
							<path d="M12,0 C5.3833008,0 0,5.3828125 0,12 C0,18.6171875 5.3833008,24 12,24 C18.6166992,24 24,18.6171875 24,12 C24,5.3828125 18.6166992,0 12,0 Z" fill="#303C42"></path>
							<path d="M12,23 C5.9345703,23 1,18.0654297 1,12 C1,5.9345703 5.9345703,1 12,1 C18.0654297,1 23,5.9345703 23,12 C23,18.0654297 18.0654297,23 12,23 Z" fill="#FED600"></path>
							<path d="M19.119751,3.630249 C20.7561646,5.5509644 21.75,8.0349121 21.75,10.75 C21.75,16.8154297 16.8154297,21.75 10.75,21.75 C8.0349121,21.75 5.5509644,20.7561646 3.630249,19.119751 C5.6494751,21.4898682 8.6496582,23 12,23 C18.0654297,23 23,18.0654297 23,12 C23,8.6496582 21.4898682,5.6494751 19.119751,3.630249 Z" fill="#010101" opacity="0.1"></path>
							<path d="M18.5,8 C18.2236328,8 18,8.2236328 18,8.5 C18,9.3271484 17.1030273,10 16,10 C14.8969727,10 14,9.3271484 14,8.5 C14,8.2236328 13.7763672,8 13.5,8 C13.2236328,8 13,8.2236328 13,8.5 C13,9.8789063 14.3457031,11 16,11 C17.6542969,11 19,9.8789062 19,8.5 C19,8.2236328 18.7763672,8 18.5,8 Z" fill="#303C42"></path>
							<path d="M11,8.5 C11,8.2236328 10.7763672,8 10.5,8 C10.2236328,8 10,8.2236328 10,8.5 C10,9.3271484 9.1030273,10 8,10 C6.8969727,10 6,9.3271484 6,8.5 C6,8.2236328 5.7763672,8 5.5,8 C5.2236328,8 5,8.2236328 5,8.5 C5,9.8789063 6.3457031,11 8,11 C9.6542969,11 11,9.8789063 11,8.5 Z" fill="#303C42"></path>
							<circle fill="#303C42" cx="12" cy="18" r="3"></circle>
							<circle fill="#B72025" cx="12" cy="18" r="2"></circle>
							<path d="M10.5,18.5 C10.5,17.3974609 11.3969727,16.5 12.5,16.5 C12.9238281,16.5 13.3156128,16.6344604 13.6394043,16.8601685 C13.27771,16.3416138 12.678894,16 12,16 C10.8969727,16 10,16.8974609 10,18 C10,18.678894 10.3417358,19.2780762 10.8605957,19.6398315 C10.6346436,19.315918 10.5,18.9239502 10.5,18.5 Z" fill="#010101" opacity="0.1"></path>
							<path d="M18.5,16 L17.434082,16 L18.9160156,13.7773437 C19.0180664,13.6240234 19.027832,13.4267578 18.9409179,13.2636718 C18.8540039,13.1015625 18.6845703,13 18.5,13 L16.5,13 C16.2236328,13 16,13.2236328 16,13.5 C16,13.7763672 16.2236328,14 16.5,14 L17.565918,14 L16.0839844,16.2226563 C15.9819336,16.3759766 15.972168,16.5732422 16.0590821,16.7363282 C16.1459961,16.8984375 16.3154297,17 16.5,17 L18.5,17 C18.7763672,17 19,16.7763672 19,16.5 C19,16.2236328 18.7763672,16 18.5,16 Z" fill="#303C42"></path>
							<path d="M21.5,13 L21.309082,13 L21.9472656,11.7236328 C22.0249023,11.5683594 22.0166015,11.3847656 21.9252929,11.2373047 C21.8339843,11.0898438 21.6733398,11 21.5,11 L20.5,11 C20.2236328,11 20,11.2236328 20,11.5 C20,11.7763672 20.2236328,12 20.5,12 L20.690918,12 L20.0527344,13.2763672 C19.9750977,13.4316406 19.9833985,13.6152344 20.0747071,13.7626953 C20.1660157,13.9101562 20.3266602,14 20.5,14 L21.5,14 C21.7763672,14 22,13.7763672 22,13.5 C22,13.2236328 21.7763672,13 21.5,13 Z" fill="#303C42"></path>
							<path d="M12,0 C5.3833008,0 0,5.3828125 0,12 C0,18.6171875 5.3833008,24 12,24 C18.6166992,24 24,18.6171875 24,12 C24,5.3828125 18.6166992,0 12,0 Z" fill="url(#linearGradient-1)"></path>
						</g>
					</g>
				</svg>
				<?php
			}
		}
	}

}
